function [done,r0,indxf]=auto_stage0(y,x,indcte,r00,rmod,alpha,f0_sig,eta)

// PURPOSE: eliminates variables whose joint significance is
// lower than f0_sig under the condition that no diagnostic
// fails
// ------------------------------------------------------------
// INPUT:
// * y = vector of the endogenous variable
// * x = matrix of the exogenous variables
// * indcte = index of the constant variable (= nvar+1 if there
//   is no constant in the r00 model)
// * r00 = results of the estimation (by ols or ols2) of the 
// model Y = X*b+U
// * rmod = a tlist defined by def_results
// ------------------------------------------------------------
// OUPTUT:
// * done = %t if all variables are significant, %f otherwise
// * r0 = results structure of the final model (the one without
//  the eliminated variables) as provided by ols2
// * indxf: indexes in x of the remaining exogenous variables
// ------------------------------------------------------------
// NOTES:
// * used by automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 

nvar=r00('nvar')
// sort pvalues by decreasing order and save in indpvalue
// their indexes
[gpvalue,indpvalue]=sort(r00('pvalue'))

if gpvalue(1) < alpha then
// the lower tstat is nevertheless significant
   r0=r00
   done=%t
   indxf=indpvalue
else
   done=%f
   r=r00
   count=0
   t1=0
   fp=1
   p=ones(size(eta,1),1)
   while (fp >= f0_sig) & (t1 < 1) & and (p > eta)...
   & (count < nvar) then
      r0=r
   // eliminate the next less significant variable from the list
   // of exogenous variables 
      count=count+1
      indxf=sort(indpvalue(count+1:nvar))
      xd=x(:,indxf)
   // estimate the new model with minimal output and use of a
   // preexisting tlist structure to save time
      r=ols1a(y,xd,rmod)
      [val,p]=test_func(r)
      [fstat,fp]=waldf0(r,r00)
      t1=abs(r('tstat')(find(indxf==indpvalue(count+1))))
   end
   if or(p <= eta) | (fp < f0_sig) then
   // the search has stopped because the last model was not
   // valid so you must not count it 
      indxf=indpvalue(count:nvar)
      xd=x(:,indxf)
      if count==1 then
         r0=ols1a(y,xd,rmod)
      end
   else
      // the last model is valid, but it cannot be simplified
      // further because there are no more (insignificant) 
      // variable to drop
      r0=r
      [val,p]=test_func(r)
   end
   // update and complete the tlist structure corresponding to
   // the last regression    
   nobs=r0('nobs')
   nvar=r0('nvar')
   resid=r0('resid')
   ediff = resid(2:nobs)-resid(1:nobs-1)
   dw = ediff'*ediff/r0('sigu')
   // durbin-watson
   condindex=bkwols(xd)
   prescte=or(indxf == indcte)
      
   r0('dw')=dw
   r0('condindex')=condindex
   r0('prescte')=prescte
   r0('namex')=r00('namex')(indxf)
   if prescte & nvar ~=1 then
   // there is a constant and at least another exogenous
   //  variable: R and Rbar make sense
      r0(1)($+1)='rsqr'
      r0(1)($+1)='rbar'
      r0(1)($+1)='f'
      r0(1)($+1)='pvaluef'
      df=nobs-nvar
      rsqr1 = r0('sigu');
      rsqr2 = r0('ym')'*r0('ym');
      rsqr = 1-rsqr1/rsqr2
      r0('rsqr') = rsqr
      // r-squared
      nobsm1=nobs-1
      nvarm1=nvar-1
      r0('rbar') = 1-rsqr1/df/rsqr2*nobsm1
      // rbar-squared
      f=rsqr/(1-rsqr)*df/nvarm1
      r0('f')=f
      r0('pvaluef') = 1-cdff("PQ",f,nvarm1,nobs-nvar)
   else 
      r('prescte')=%f
   end
   r0('spec_test')=[val p]
end
