function [listeq]=auto_stage1(y,x,listeq,indx,indcte,firstelim,r00,rmod,alpha,eta)

// PURPOSE: starting from the variable whose index in indx is
// firstelim, find a path where: the less significant variable
// which does not make the specification tests calculated in
// test_func fails is successively withdrawn until :
// 1) either the withdrawn variables as a group has been
//   already encountered on another path
// 2) or all remaining variables are non significant or make
// the specification tests calculated in test_func fail
// ------------------------------------------------------------
// INPUT:
// * y = vector of the endogenous variable
// * x = matrix of the exogenous variables
// * listeq = the list containing all preceding paths and the
//   corresponding estimation results
// * index = the indexes of the x variables remaining at the
//   entry of the function
// * indcte = the booelan indicating the presence or the 
//   absence of the constant in the regression
// * firstelim = the index of the first variable which is
//   withdrawn to begin the path
// * r00 = the results tlist for the regression containing all
//   exogenous variables whose index is in indx
// * rmod = a tlist defined by def_results
// ------------------------------------------------------------
// OUPTUT:
// * listeq = the entry list plus the path followed here and,
//   if it leads to a new model, the corresponding estimation
//   results
// ------------------------------------------------------------
// NOTES:
// * used by automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 


// set initial values 
endst1=%f
previouspath=%f
nvarelim=1
path=[]
valpath=%f
nx=size(indx,1)

// withdraw the variable whose number has been given and
// estimate the corresponding model
indsuppr=indx(firstelim)
indx(firstelim)=[]
xpath=x(:,indx)
r=ols1a(y,xpath,rmod)
[val,p]=test_func(r)

if (and(p >= eta)) then
// none of the specification tests fails, the path
// is a valid one
   valpath=%t
   path=indsuppr 

   while ~endst1
   // search for an insignificant variable to withdraw
      nvarelim=nvarelim+1
      [gpvalue,indpvalue]=sort(r('pvalue'))
      nonsignif=size(indpvalue(gpvalue > alpha),1)
      
      if nonsignif == 0 then
      // no reduction is now possible
         endst1=%t
      else
         n=0
         p=zeros(size(p,1),1)

         while (or(p < eta)) & n < nonsignif
         // one of the specification tests fails, re-introduce the removed
         // variable and try the next least-significant variable
            n=n+1
            indsuppr=indx(indpvalue(n))
            indx(indpvalue(n))=[]
            xpath=x(:,indx)
            r=ols1a(y,xpath,rmod)
            [val,p]=test_func(r)

            if or(p<eta) then
               // add again the removed variable
               indx=[indx(1:indpvalue(n)-1) ; indsuppr ; indx(indpvalue(n):$)]
            end
         end
         if or(p<eta) then
         // no reduction is now possible
            endst1=%t
               // the last estimation in the preceding loop is not valid 
            xpath=x(:,indx)
            r=ols1a(y,xpath,rmod)
            [val,p]=test_func(r)
         else
         // updates the path
            path=[path indsuppr]
            npath=size(path,2)
            ordpath=sort(path)
            for i=1:length(listeq)/3
               npathi=size(listeq(3*i-2),2)
               if npathi >= npath then
                  ordpathi=sort(listeq(3*i-2)(1:npath))
                  if ordpath == ordpathi then
                     //path already encoutered: stop there         
                     previouspath=%t
                     endst1=%t
                  end
               end
            end
         end
      end
   end
end

if valpath then   
   if previouspath then
      listeq($+1)=path
      listeq($+1)=[]
      listeq($+1)=[]      
   else
      listeq($+1)=path
      listeq($+1)=indx
      prescte=or(indx == indcte)
      resid=r('resid')
      ediff = resid(2:nobs)-resid(1:nobs-1)
      dw = ediff'*ediff/r('sigu')
      // durbin-watson

      condindex=bkwols(xpath)
      
      r('dw')=dw
      r('condindex')=condindex
      r('prescte')=prescte

      nvar=r('nvar')
      if prescte & nvar ~=1 then
         // there is a constant and at least another exogenous variable:
         // R and Rbar make sense
         r(1)($+1)='rsqr'
         r(1)($+1)='rbar'
         r(1)($+1)='f'
         r(1)($+1)='pvaluef'
         df=nobs-nvar
         rsqr1 = r('sigu');
         rsqr2 = r('ym')'*r('ym');
         rsqr = 1-rsqr1/rsqr2
         r('rsqr') = rsqr
         // r-squared
         nobsm1=nobs-1
         nvarm1=nvar-1
         r('rbar') = 1-rsqr1/df/rsqr2*nobsm1
         // rbar-squared
         f=rsqr/(1-rsqr)*df/nvarm1
         r('f')=f
         r('pvaluef') = 1-cdff("PQ",f,nvarm1,nobs-nvar)
      else
         r('prescte')=%F
      end
      r('spec_test')=[val p]
      r('namex')=r00('namex')(indx)
      r('aic')=log(r('sigu')/nobs)+r('nvar')*2/r('nobs')
      r('bic')=log(r('sigu')/nobs)+r('nvar')*log(r('nobs'))/r('nobs')
      r('hq')=log(r('sigu')/nobs)+r('nvar')*2*log(log(r('nobs')))/r('nobs')
      listeq($+1)=r
   end
end
  