function [results]=ols1a(y,x,results)

// PURPOSE: one of the numerous functions performing ordinary
// least squares: this one assumes that x et y are already a 
// matrix, and a vector, that a result structure exists which 
// can be filled and does not provide DW, R statistics 
// ------------------------------------------------------------
// INPUT: 
// * y = dependent variable vector (nobs x 1)
// * x = independent variables matrix (nobs x nvar)
// * results: an existing tlist of regression results
// ------------------------------------------------------------
// OUTPUT: 
// a tlist with:
//        results('meth')  = 'ols'
//        results('beta')  = bhat
//        results('tstat') = t-stats
//        results('yhat')  = yhat
//        results('resid') = residuals
//        results('sige')  = e'*e/(n-k)
//        results('rsqr')  = rsquared
//        results('rbar')  = rbar-squared
//        results('dw')    = Durbin-Watson Statistic
//        results('nobs')  = nobs
//        results('nvar')  = nvars
//        results('y')     = y data vector
//        results('x')     = x data matrix
//
// ------------------------------------------------------------
// NOTES: 
// used by automatic(), auto_stage0(), 
// ------------------------------------------------------------
// Copyright: Eric Dubois 
// adapted from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatial-econometrics.com

[nobs,nvar]=size(x)

xpxi=invxpx(x)
bet=xpxi*x'*y
yhat = x*bet
resid = y-yhat
sigu =resid'*resid
sige= sigu/(nobs-nvar)
//ser=sqrt(sige)
vcovar=sige*xpxi
//tmp = diag(vcovar);
tstat = bet ./ sqrt(diag(vcovar))

df=nobs-nvar
pvalue=ones(nvar,1)
for i=1:nvar
   pvalue(i)=(1-cdft("PQ",abs(tstat(i)),df))*2
end

results('x') = x
results('nvar')  = nvar
results('beta')  = bet
results('tstat') = tstat
results('pvalue') = pvalue
results('resid') = resid
results('vcovar') = vcovar
results('sige') = sige
results('sigu') = sigu
results('ser') = sqrt(sige)
results('yhat') = yhat
