function []=expbd2exc(grocer_bd,grocer_output,grocer_sep,transpose) 

// PURPOSE: export the content of a data base or a list of
// variables bd to a file that Excel can read
//-------------------------------------------------------------
// INPUT:
// * grocer_bd = the name of a database or of a list of ts
// loaded in the environment
// * grocer_output = the excel file where to save the data
// * sep = decimal separator (optional: if not given then sep= '.')
// * transpose=anything but optional: if given then series are
//   exported in rows instead of columns
//-------------------------------------------------------------
// OUTPUT: 
// nothing
//-------------------------------------------------------------
// Copyright Eric Dubois 2004

if typeof(grocer_bd) ~= 'list' then
   load(grocer_bd)
   grocer_bd=dblist(grocer_bd)
   grocer_nvar=size(grocer_bd,1)
else
   grocer_nvar=length(grocer_bd)
end

[nargout,nargin]=argn(0)
if nargin == 2 then
   grocer_sep='.'
end

grocer_x=evstr(grocer_bd(1))
select typeof(grocer_x)
case 'ts' then
   grocer_fq=grocer_x('freq')
   grocer_d=grocer_x('dates')
   grocer_dmin=grocer_d(1)
   grocer_dmax=grocer_d(size(grocer_d,1))

   for grocer_i=2:grocer_nvar
      grocer_ts=evstr(grocer_bd(grocer_i))
      grocer_fq2=grocer_ts('freq')
      if grocer_fq2 ~= grocer_fq then
         error('all ts have not the same frequency')
      end
      grocer_d=grocer_ts('dates')
      grocer_dmin=min(grocer_d(1),grocer_dmin)
      grocer_dmax=max(grocer_d(size(grocer_d,1)),grocer_dmax)
   end

   grocer_m2tobexported=emptystr(grocer_dmax-grocer_dmin+2,grocer_nvar+1)+' '
   grocer_dat=num2date([grocer_dmin:grocer_dmax],grocer_fq)
   grocer_m2tobexported(:,1)=['dates' ; string(grocer_dat)']

   for grocer_i=1:grocer_nvar
      grocer_ts=evstr(grocer_bd(grocer_i))
      grocer_d=grocer_ts('dates')

      grocer_m2tobexported(1,grocer_i+1)=grocer_bd(grocer_i)
      grocer_m2tobexported(grocer_d(1)-grocer_dmin+2:...
      grocer_d(size(grocer_d,1))-grocer_dmin+2,grocer_i+1)=string(grocer_ts('series'))
   end

case 'constant' then
 
   grocer_nd=size(grocer_x,1)*size(grocer_x,2) 
   grocer_m2tobexported=emptystr(grocer_nd+1,grocer_nvar)+' '
   for grocer_i=1:grocer_nvar
      grocer_m2tobexported(1,grocer_i)=grocer_bd(grocer_i)
      grocer_m2tobexported(2:grocer_nd+1,grocer_i)=string(evstr(grocer_bd(grocer_i)))
   end

else 
   error(typeof(grocer_x)+' is not a valid type for the exportation to excel')
end

if grocer_sep ~= '.' then
   grocer_m2tobexported=strsubst(grocer_m2tobexported,'.',grocer_sep)
end

if nargin == 4 then
   grocer_m2tobexported=grocer_m2tobexported'
end

sci2excel(grocer_m2tobexported,grocer_output)
