function [grocer_y,grocer_namey,grocer_x,grocer_namexos,grocer_prests,grocer_boundsvarb]=explouniv(grocer_namey0,grocer_lx)

// PURPOSE: explode endogenous and exogenous variables into
// matrices, names and define corresponding bounds
// ------------------------------------------------------------
// INPUT:
// * grocer_namey0 = a time series, a real (nx1) vector or a  
// string equal to the name of a time series or a (nx1) real
// vector between quotes
// * grocer_lx = list of exogenous variables:
//   each element could be
//   - a timeseries, a real vector, 
//   a real matrix or a string (the name of a variable with
//   one of the types cited above, between quotes)
//   - a matrix of strings, each one being the name of a
//   variable
//   - the string 'cte' or 'const' if the user wants a constant 
//     to be included automatically
// ------------------------------------------------------------
// OUTPUT: 
// * grocer_y = a (Tx1) real vector or a ts
// * grocer_namey = a string
// * grocer_x = a (T x k) real matrix  
// * grocer_namexos = a (1 x k) string vector
// * grocer_prests = a boolean indicating whether there is a ts
// in grocer_x
// * grocer_boundsvarb = a (2 x 1) string matrix (of dates)
// ------------------------------------------------------------
// Copyright: Eric Dubois 2004


// explode namey into the corresponding variable, its name, if
// it's a ts and if necessary the admissible bounds
[grocer_y,grocer_namey,grocer_prests,grocer_boundsvarb]=...
exploy(grocer_namey0)

// explode the list of the arguments into the corresponding
// variable, its name, and, if necessary updates the bounds
[grocer_x,grocer_namexos,grocer_boundsvarb]=...
explox(grocer_lx,'exogenous',grocer_boundsvarb)

// if necessary, define y on the admissible bounds
if typeof(grocer_y) == 'ts' then
   grocer_y=ts2vec(grocer_namey0,grocer_boundsvarb)
else
   if typeof(grocer_y) ~= 'constant' then
      error('exogenous variable '+grocer_namey+' is neither a ...
            time series nor a constant vector')
   end
end

grocer_presna=or(isnan(grocer_y))
if or(grocer_presna) then
   error('series '+grocer_namey+' contains Nan in the range you have specified')
end 

grocer_presna=find(or(isnan(grocer_x),'r'))
for i=1:size(grocer_presna,2)
   error('series '+grocer_namexos(grocer_presna(i))+' contains Nan in the range you have specified')
end 

