function [grocer_y,grocer_namey,grocer_prests,grocer_b]=exploy(grocer_namey)

// PURPOSE: from a variable grocer_namey, store the values of 
// the corresponding series in a vector, and, if necessary,
// define the admissible estimation bounds
// ------------------------------------------------------------
// INPUT:
// * grocer_namey = a variable which can be a timeseries, a 
//   real vector or a string (the name of a variable with
//   one of the types cited above, between quotes), 
// ------------------------------------------------------------
// OUPTUT:
// * grocer_y = a (Tx1) real vector or a ts
// * grocer_namey = a string
// * grocer_prests = a boolean indicating if y is or is not a
//   ts
// * grocer_b = a (px1) string matrix (of dates)
// ------------------------------------------------------------
// NOTES:
// used by the following functions:
// ols(), olsc(), automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 

grocer_prests=%f
// define the name of the variable y and the vector of values
if typeof(grocer_namey) == 'string' then
   grocer_y=evstr(grocer_namey)
else
   grocer_y=grocer_namey
   grocer_namey='endogenous'
end

if exists('grocer_boundsvar') then
   grocer_b=grocer_boundsvar
else
   grocer_b=[]
end

select typeof(grocer_y) 

case 'ts' then
   grocer_prests=%t
   if grocer_b == [] then
      grocer_d=datets(grocer_y)
      indnonna=find(~isnan(grocer_y('series')))
      if indnonna == [] then
         error('input series has only NA values')
      end
      firstnonna=indnonna(1)
      delnonna=indnonna-[firstnonna:firstnonna-1+size(indnonna,2)]
      consnonna=find(delnonna==0)
      lastnonna=consnonna(size(consnonna,2))+firstnonna-1
      grocer_fq=freqts(grocer_y)
      grocer_b=num2date([grocer_d(firstnonna);grocer_d(lastnonna)],grocer_fq)
   end

case 'constant' then
   nc=size(grocer_y,2)
   if nc ~= 1 then
      error(grocer_namey+' should be a column vector')
   end

else
   error('not an admissible type for '+grocer_namey)
end

