function [] = impexc2bd(filein,sep,fileout) 

// PURPOSE: importation of an excel file saved under csv format
// ------------------------------------------------------------
// INPUT:
// * filein = name of the file to be imported (between quotes)
// * sep = separator used in the filein (between quotes)
// * fileout = name of the scilab file where to save the 
// imported data (between quotes)
// ------------------------------------------------------------
// OUTPUT: nothing; the imported series are saved in the file
// named fileout
// ------------------------------------------------------------
// NOTES:
// * if one data is named dates or DATES (scilab distinguish
// capitals from small letters) then the following data are 
// saved as timeseries
// * if a value is lacking or #N/A in a timeseries, it is given
// a NA value
// ------------------------------------------------------------
// Copyright: Eric Dubois 
// (with a few lines of code from the scilab group)

prests=%f
savevar="save("+''''+fileout+''''
grocer_content=[]

[lhs,rhs]=argn(0)
if rhs<2 then sep=',',end

v=read(filein,-1,1,'(a)')+';'
nl=size(v,1)

// read the first line, to fix the # of colums nc
line=v(1)
ln=length(line)
indsep2=strindex(line,sep)-1

endline=[]
// deal the case when the ending character is not the separator:
// it can alas happen!
if indsep2(size(indsep2,2)) ~= ln-1 then
   endline=1
end
indsep2=[indsep2 endline*(ln-1)]
indsep1=[1 indsep2+2]
nc=size(indsep2,2)
mat=emptystr(nl,nc)

if ln ~= nc then
   for i=1:nc
      mat(1,i)=part(line,indsep1(i):indsep2(i))
   end
end

// read the file, extract each cell of the file and fill
// the predefined matrix mat
for i=2:nl
  line=v(i)
  ln=length(line)
  if ln ~= nc then
     indsep2=[strindex(line,sep)-1 endline*(ln-1)]
     indsep2=[indsep2 endline]
     indsep1=[1 indsep2+2 ]
     nsep=size(indsep2,2)
     for j=1:nsep
        mat(i,j)=part(line,indsep1(j):indsep2(j))
     end
  end
end

if nc ~=1 then
   carnum=part(mat(1,2),1)
   if (ascii(carnum) < 46 | ascii(carnum) > 57) & carnum ~= '-' then
      // suspect that names are given in a row and not in a column
      mat=mat'
   end
else
   mat=mat'
end

[nl,nc]=size(mat)
emptycol=emptystr(nl,1)
while and(strsubst(mat(:,nc),' ','') == emptycol) & nc >1 then
   nc=nc-1
end
mat=mat(:,1:nc)

for i=1:nl
   nomvar=strsubst(mat(i,1),' ','_')
   lvar=length(nomvar)
   if lvar ~=0 & size(strindex(nomvar,' '),2) ~= lvar then
   // if variable has no name (a case which may occur 
   // with .csv files), then ignore it
      if (convstr(nomvar) == 'dates') then
         dat=convstr(mat(i,2:nc)')
         prests=%t
         if or(dat == '') then
            error('incomplete dates in your csv file')
         end
         fq=date2fq(dat(1))
         dat=date2num_m(dat)
         nbdat=size(dat,1)
         if or(dat(2:nbdat)-dat(1:nbdat-1) ~= 1) then
            error('dates are not contiguous in yoy database')
         end
      elseif (part(convstr(nomvar),1:5) == 'names') then
         nomvar=part(nomvar,strindex(nomvar,'(')+1:strindex(nomvar,')')-1)
         execstr(nomvar+'=mat(i,2:nc)''')
         savevar=savevar+","+nomvar
         grocer_content=[grocer_content ; nomvar']
      else
         r=mat(i,2:nc)'
   // deal now with the na values; 2 possibilities are considered
   // here: a #N/A (default value in EXCEL) and an empty string;
   // other cases can be added when and if needed
         lna=r=='#N/A'|strsubst(r,' ','')==''
         r(lna)='%nan'
         if prests then
            exvar=nomvar+'=tlist([''ts'';''freq'';''dates'';...
                  ''series''],fq,dat,evstr(r))'
            execstr(exvar)
         else
            exvar=nomvar+"=evstr(r)"          
            execstr(exvar)
         end
         grocer_content=[grocer_content ; nomvar]
         savevar=savevar+","+nomvar
      end
   end
end

savevar=savevar+",grocer_content)"
execstr(savevar)
