function [t]=studentize(x)

// PURPOSE: If x is a vector, substract its mean and divide
//          by its standard deviation. If x is a matrix, 
//          do the above for each column.
//---------------------------------------------------
// USAGE:   out = studentize(x)
// where:     x = a vector or matrix
//---------------------------------------------------
// RETURNS:
//          out = transformed matrix
// --------------------------------------------------
// Copyright Eric Dubois 2002
// adapted from: 
// Kurt.Hornik@ci.tuwien.ac.at  
// Dept of Probability Theory and Statistics TU Wien
 
 
[nobs,nvar] = size(x);
 
if nvar==1 then
  if st_deviation(x)==0 then
     t = zeros(nobs,1);
  else
     t = (x-mean(x))/st_deviation(x);
  end
elseif nvar>1 then
   t=ones(nobs,nvar)
   for i=1:nvar
      if st_deviation(x(:,i))==0 then
        t(:,i) = zeros(nobs,1);
      else
         t(:,i) = (x(:,i)-mean(x(:,i)))./st_deviation(x(:,i))
      end
   end

else
  error('studentize:  x must be a vector or a matrix');
end
 
