function [resulkpss]=kpss(grocer_namey,grocer_p,grocer_l,grocer_np)

// PURPOSE: performs the KPSS test
// ------------------------------------------------------------
// REFERENCES:  Kwiatkowski, D., P. Phillips, P. Schmidt, and
// Y. Shin (1992), "Testing the Null of Stationarity Against
// the Alternative of a Unit Root", Journal of Econometrics 54,
// pp. 159-178.
// ------------------------------------------------------------
// * grocer_namey = a time series, a real (nx1) vector or a  
// string equal to the name of a time series or a (nx1) real
// vector between quotes
// * grocer_p=order of time polynomial in the null-hypothesis
//      grocer_p =  0, for constant term
//      grocer_p =  1, for constant plus time-trend 
// * grocer_l (optional) = truncation lag of the Newey-West
//   windows
//   default : l= floor(5*nobs^0.25)
// * grocer_np (optional) = 'noprint' if the user doesn't want
// to print the results of the regression
// ------------------------------------------------------------
// OUPTUT:
// resulkpss = results tlist with:
//  . resulkpss('meth') = 'kpss'
//  . resulkpss('namey') = namey
//  . resulkpss('y') = y
//  . resulkpss('t') = t
//  . resulkpss('lag(N_W)') = l
//  . resulkpss('test_value') = lm
//  . resulkpss('prests') = prests
//  . resulkpss('1% level') = 1% critical value
//  . resulkpss('51% level') = 5% critical value
//  . resulkpss('10% level') = 10% critical value
//  . resulkpss('bounds') = bounds fo the regression (if any)
// ------------------------------------------------------------
// Copyright: Eric Dubois

grocer_prt=%t
tab=[0.739 0.463 0.347 ;
     0.216 0.146 0.119]

[nargout,nargin]=argn(0)

// explode namey into the corresponding variable, its name, if
// it's a ts and if necessary the admissible bounds
[y,namey,prests,boundsvarb]=exploy(grocer_namey)

// if necessary, define y on the admissible bounds
if typeof(y) == 'ts' then
   y=ts2vec(y,boundsvarb)
else
   if typeof(y) ~= 'constant' then
      error('variable '+namey+' is neither a ...
            time series nor a constant vector')
   end
end

if prests & exists('grocer_boundsvar') then
   if size(grocer_boundsvar,1) ~= 2 then
      error('bounds are discontinous in kpss')
   end
end

nobs=size(y,1)
[nargout,nargin] = argn(0)
select nargin
case 4 then
   if grocer_np == 'noprint' then
      prt=%f
   else
      error('argument 4 in adf should be ''noprint''')
   end
case 3 then
   if typeof(grocer_l) ==  'string' then
      if grocer_l == 'noprint' then
        grocer_prt=%f
        grocer_l=floor(5*nobs^0.25)
      else       
         error('argument 3 in adf cannot be: '+grocer_l)
      end
   elseif typeof(grocer_l) ~= 'constant' then 
      error('argument 3 in adf cannot have the type: '+typeof(grocer_l))
   end
case 2 then
   grocer_l=floor(5*nobs^0.25)
else
   error('invalid number of arguments')
end

r=ols1(y,ptrend(grocer_p,nobs))
e=r('resid')(1)
for i=2:nobs
   e=[e ; e(i-1)+r('resid')(i)]
end
sigma2=newey_west(r('resid'),grocer_l)  
lm=sum(e.^2)/sigma2/nobs^2


resulkpss=tlist(['results';'meth';'namey';'y';'p';'lag(N_W)';...
'test_value';'prests';'1% level';'5% level';'10% level'],...
'kpss',namey,y,grocer_p,grocer_l,lm,prests,tab(grocer_p+1,1),..
tab(grocer_p+1,2),tab(grocer_p+1,3))
if prests then
   resulkpss(1)($+1) = 'bounds'
   resulkpss('bounds') = boundsvarb
end
 
if grocer_prt then
   prtunitr(resulkpss)
end