function [contrib_x]=contrib(vari,mainf_proxy)

// PURPOSE: Calculates contribution of variable vari to the 
// evolution of an endogenous variable, with response function
// mainf_proxy
// ------------------------------------------------------------
// INPUT:
// * vari = the exogenous varaible, either a ts, a vector or
//   such an object
// * mainf_proxy = the nbterms first terms of the Infinite
// Moving average
// ------------------------------------------------------------
// OUTPUT:
// * contrib_x = the vector of contributions 
// ------------------------------------------------------------
// Copyright: Eric Dubois 2003 


// explode namey into the corresponding variable, its name, if
// it's a ts and if necessary the admissible bounds
[vec_vari,namey,grocer_prests,grocer_boundsvarb]=...
exploy(vari)

// if necessary, define y on the admissible bounds
if typeof(vec_vari) == 'ts' then
   vec_vari=ts2vec(vec_vari,grocer_boundsvarb)
else
   if typeof(vec_vari) ~= 'constant' then
      error('variable  is neither a time series nor a constant vector')
   end
end

nobs=size(vec_vari,1)
nbmainf=size(mainf_proxy,1)

if nobs >  nbmainf then
   warning('# of terms in the response function are lower than ...
     the # of observations')
end   

contrib_x=ones(nobs,1)
for i=1:nobs
   j=min(i,nbmainf)
   contrib_x(i)=vec_vari(1+i-j:i)'*mainf_proxy(j:-1:1)
end

if grocer_prests then
   contrib_x=vec2ts(contrib_x,grocer_boundsvarb)
end
