function [condindex]=bkw(varargin)

// PURPOSE: computes and prints BKW colinearity 
// variance-decomposition proportions matrix
// ------------------------------------------------------------
// INPUT:
// varargin = arguments which can be:
//   . a time series
//   . a real (nxp) vector 
//   . a string equal to the name of a time series or a (nxp) 
//     real vector between quotes
//   . the string 'noprint' if the user doesn't want to print
//     the results of the regression
// ------------------------------------------------------------
// OUTPUT:
// condindex = the condition number 
// ------------------------------------------------------------
// PRINTS: 
// the variance-decomposition proportions matrix
// ------------------------------------------------------------
// REFERENCES: Belsley, Kuh, Welsch, 1980 Regression Diagnostics
// ------------------------------------------------------------
// Copyright Eric Dubois 2002
// adapted from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatia-econometrics.com


// explode the list of the arguments into the corresponding
// variables and their names
grocer_lx=varargin
[x,namexos]=explox(grocer_lx,'exogenous')
nx=size(x,2)

[u,d,v] = svd(x,0);

lamda = diag(d(1:nx,1:nx));
lamda2 = lamda .* lamda;
v = v .* v;
 
phi = zeros(nx,nx);
for i = 1:nx
  phi(i,:) = v(i,:) ./ lamda2';
end
 
 
pi = ones(nx,nx);
for i = 1:nx
  phik = sum(phi(i,:))
  pi(i,:) = phi(i,:)/phik;
end
 
// BUG fix suggested by 
// John P. Burkett <burkett@uriacc.uri.edu
lmax = lamda(1);
lmaxvec = lmax*ones(nx,1);
lout = lmaxvec ./ lamda;
 
disp(' Belsley, Kuh, Welsch Variance-decomposition (in %)');
disp(' ')

mat2print=['K(x)']
for i=1:nx
   mat2print = [mat2print string(round(lout(i)))]
end

for i=1:nx
   row2print = [namexos(i)]
   for j=1:nx
     row2print = [row2print string(round(pi(i,j)*100))]
   end
   mat2print = [mat2print ; row2print]
end

printmat(mat2print,%io(2))

condindex=round(lout(nx))
