function [condindex]=bkwols(x)

// PURPOSE: computes BKW COND index of a x matrix
// ------------------------------------------------------------
// REFERENCES: Belsley, Kuh, Welsch, 1980 Regression 
// Diagnostics
// ------------------------------------------------------------
// INPUT:
// x = independent variables matrix (nobs x nvar)
// ------------------------------------------------------------
// OUTPUT: 
// condindex = the COND index
// ------------------------------------------------------------
// NOTES:
// * used by ols2(), ols2a(), olsc()
// * see also bkw(),dfbeta(), rdiag(), diagnose()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
// adapted from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatia-econometrics.com

[nobs,nargin]=size(x)

[u,d,v] = svd(x,0);
 
lamda = diag(d(1:nargin,1:nargin));
lamda2 = lamda .* lamda;
v = v .* v;
 
phi = zeros(nargin,nargin);
for i = 1:nargin
  phi(i,:) = v(i,:) ./ lamda2';
end
 
 
pi = zeros(nargin,nargin);
for i = 1:nargin
  phik = sum(phi(i,:))
  pi(i,:) = phi(i,:)/phik;
end
 
// BUG fix suggested by 
// John P. Burkett <burkett@uriacc.uri.edu
lmax = lamda(1);
lmaxvec = lmax*ones(nargin,1);
lout = lmaxvec ./ lamda;
condindex=round(lout(nargin))
