function [rjbnorm]=jbnorm(res,np)

// PURPOSE : Jarque and Bera normality test
// ------------------------------------------------------------
// references : Jarque, C. M., and Bera, A. K. (1980). '
// Efficient tests for normality, homoscedasticity and serial
// independence of regression residuals', Economics Letters, 6,
// 255259.
// ------------------------------------------------------------
// INPUT:
// * res = a result tlist
// * np= the string 'noprint' if the user doesn't want to print
//     the results of the test
// ------------------------------------------------------------
// OUTPUT: 
// rjbnorm= a typed list with :
//   . rjbnorm('meth') = 'jbnorm' 
//   . rjbnorm('r1st') = results of the first step 
//      regression (allows the "traceability" of the results)
//   . rjbnorm('chistat') = the value of the chi2 statistics
//   . rjbnorm('chi_pvalue') = the corresponding p-value 
//   . rjbnorm('chi_df') = the corresponding degrees of
//     freedom
// ------------------------------------------------------------
// PRINTS: If the user has not given the argument 'noprint',
// the results of the test
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002

[nargout,nargin]=argn(0)
if nargin == 1 then
   prt=%t
else
   if np == 'noprint' then
      prt=%f
   else
      error('argument 2 in jbnorm should be ''noprint''')
   end
end 
        
[jb,pn]=jbnorm0(res)

rjbnorm=tlist(['results';'meth';'r1st';'chistat';'chi_df';'chi_pvalue'],...
'jbnorm',res,jb,2,pn)

if prt then
   prtchi(rjbnorm)
end
