function [fstat,fprb,dfnum,dfden]=waldf0(resultr,resultu)

// PURPOSE: computes Wald F-test for two regressions
// ------------------------------------------------------------
// INPUT:
// * resultr = results tlist from ols() restricted regression
// * resultu = results tlist from ols() unrestrcted regression
// ------------------------------------------------------------
// OUTPUT: 
// * fstat = {(essr - essu)/#restrict}/{essu/(nobs-nvar)} 
// * fprb  = marginal probability for fstat
// ------------------------------------------------------------
// PRINTS:
// (if the user hase entered 'noprint' as third argument)
// the results of the test and its signifcance level
// ------------------------------------------------------------
// NOTE:  large fstat => reject the restrictions as inconsisent 
//                       with the data
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
// adapted from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatial-econometrics.com
 

if typeof(resultr) ~= 'results' then
  error('waldf requires an ols results tlist as first input');
end
if typeof(resultu) ~= 'results' then
  error('waldf requires an ols results tlist as second input');
end

// get nobs, nvar from unrestricted and restricted regressions
nu = resultu('nobs');
nr = resultr('nobs');
ku = resultu('nvar');
kr = resultr('nvar');

if nu~=nr then
  error('waldf: the # of obs in the results tlists are ...
         different');
end
if (ku-kr)<0 then
  // flag reversed input arguments
  error('waldf: negative dof, check for reversed input ...
        arguments');
end

// recover residual sum of squares from .sige field of the result structure
epeu = resultu('sige')*(nu-ku);
eper = resultr('sige')*(nr-kr);
dfnum = ku-kr;
// find # of restrictions
dfden = nu-ku;
// find denominator dof
fstat1 = (eper-epeu)/dfnum;
// numerator
fstat2 = epeu/dfden;
// denominator
fstat = fstat1/fstat2;
 
fprb = 1-cdff("PQ",fstat,dfnum,dfden);

