function [rnd]=bino_rnd(N,p,r,c)

// PURPOSE: random sampling from a binomial distribution
// ------------------------------------------------------------
// INPUT:
// * p = the probability of success (scalar)
// * n = number of trials (scalar)
// * r,c = size of random sample from binominal(n,p) 
// distribution (optional; default=1,1)
// ------------------------------------------------------------
// OUPTUT:
// t = n-vector of random draws from the beta(a,b) distribution
// ------------------------------------------------------------
// NOTE:  mean = a/(a+b), variance = ab/((a+b)*(a+b)*(a+b+1))
// ------------------------------------------------------------
// Copyright: Eric Dubois 
// Written by KH (Kurt.Hornik@ci.tuwien.ac.at)
// converted to MATLAB by
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatial-econometrics.com
// and adapted (very freely !) to scilab by Eric Dubois
 
 
[nargout,nargin] = argn(0) 
select nargin
case 2 then
   r=1
   c=1
case 4 then 
   if r~=round(r)|c~=round(c) then
      error('r and c should be integers')
   end
else
   error('wrong number of arguments in bino_rnd')
end 
 
tmp = rand(r*c,N,'u');
rnd = matrix(sum(tmp<p,2),r,c);
