function [P,Q,U1,U2,iR,iS]=Bkjordan(A,cut)

// PURPOSE: Computes the decomposition:
// A = [U1 U2]*diag(P,Q)*inv([U1 U2])
// ------------------------------------------------------------
// INPUT:
// * A= a (nxn) matrix
// * cut = a scalar
// ------------------------------------------------------------
// OUTPUT:
// * P = a (px1) vector that stores the eigenvalues of A
// greater or equal than cut, 
// * Q = a ((n-p)x1) vector that stores the eigenvalues of A
// lower than cut, 
// * U1 = a (nxp) matrix
// * U2 = a (nx(n-p)) matrix
// * iU1 = a (nxp) matrix
// * iU2 = a (nx(n-p)) matrix
// ------------------------------------------------------------
// Copyright Jaime Terceiro, 1997/
// Eric Dubois 2003 for the Scilab translation

 
[T,U,iU,eigen] = Bkdiag(A);
 
k1 = abs(eigen)>=cut;
k2 = ~k1;
sk1 = sum(k1);
sk2 = sum(k2);
 
if sk1&sk2 then
  P = T(k1,k1);
  U1 = U(:,k1);
  iR = iU(k1,:);
  Q = T(k2,k2);
  U2 = U(:,k2);
  iS = iU(k2,:);
elseif sk2 then
  P = [];
  U1 = [];
  iR = [];
  Q = A;
  %v1=size(A)
  U2 = eye(%v1(1),%v1(2));
  iS = U2;
else
  Q = [];
  U2 = [];
  iS = [];
  P = A;
  %v1=size(A)
  U1 = eye(%v1(1),%v1(2));
  iR = U1;
end
