function [f,innov,ssvect]=lfmod(theta,theta2mat,z)

// LFMOD    - Computes the exact likelihood function of a general SS model.
//    [f, innov, ssvect] = lfmod(theta, theta2mat, z)
// theta    > parameter vector.
// theta2mat      > matrix which stores a description of the model dynamics.
// z        > matrix of observable variables.
// f        < value of the likelihood function.
// innov    < (optional) stores the sequence of innovations.
// ssvect   < (optional) stores the sequence of estimates of the state
//            vector.
// 
// 7/3/97
// Copyright (c) Jaime Terceiro, 1997
 
[nargout,nargin] = argn(0)
if nargin<3 then
   e4error(3);
end
 
saveinn = 0;
if nargout>=2 then
   saveinn = 1;
end
savessv = 0;
if nargout==3 then
   savessv = 1;
end

saveinn=int(nargout/2)
savessv=int(nargout/3)

[Phi,Gam,E,H,D,C,Q,S,R] = theta2ss(theta,theta2mat);
n = size(z,1);
m = size(H,1);
r = size(Gam,2);
 

if (grocer_e4_econd==2)&(~saveinn) then
  MV = 1;
else
  MV = 0;
end
 
if size(z,2)~=(m+r) then
  e4error(11);
end
 
if grocer_e4_filtk then
  if grocer_e4_vcond==4 then
    [x0,Sigm,ign,ign,ign,P0,iSigm,nonstat] = lfmodini(Phi,Gam,E,H,D,C,Q,S,R,z,grocer_e4_MV);
    %v2=size(Sigm)
    P0 = zeros(%v2(1),%v2(2));
  else
    [x0,P0] = lfmodini(Phi,Gam,E,H,D,C,Q,S,R,z,grocer_e4_MV);
  end
  CRCt = C*R*C';
  ESCt = E*S*C';
  EQEt = E*Q*E';
else
  if grocer_e4_vcond==4 then
    [x0,B0,K0,y0,M0,Sigm,iSigm,nonstat] = lfmodini(Phi,Gam,E,H,D,C,Q,S,R,z,MV);
  else
    [x0,B0,K0,y0,M0] = lfmodini(Phi,Gam,E,H,D,C,Q,S,R,z,MV);
  end
  B1 = B0;
  K1 = K0;
  M1 = M0;
  y1 = y0;
end
 
if MV|grocer_e4_vcond==4 then
  l = size(Phi,1);
  Phibb0 = eye(l,l);
  WW = zeros(l,l);
  WZ = zeros(l,1);
end
 
if savessv then
  ssvect = zeros(n+1,size(x0,1));
  ssvect(1,:) = x0';
end
if saveinn then
  innov = zeros(n,m);
end
 
ff = 0;
 
for t = 1:n
  // main loop
  // 
   if r then
      z1 = z(t,1:m)'-H*x0-D*z(t,m+1:m+r)';
   else
      z1 = z(t,:)'-H*x0;
   end

   if saveinn then
      innov(t,:) = z1';
   end
   if grocer_e4_filtk then
     B1 = H*P0*H'+CRCt;
   end
   
   if grocer_e4_scaleb then
      U = cholp(B1,abs(B1));
   else
      U = cholp(B1);
   end
   U = cholp(B1,grocer_e4_scaleb*abs(B1));
   %v1=size(U)
   iB1 = eye(%v1(1),%v1(2))/U/U';
   
   if grocer_e4_filtk then
    // 
      K1 = (Phi*P0*H'+ESCt)/U/U';
      if r then
         x1 = Phi*x0+Gam*z(t,m+1:m+r)'+K1*z1;
      else
         x1 = Phi*x0+K1*z1;
      end
      Phib = Phi-K1*H;
      P1 = Phib*P0*Phib'+EQEt+K1*CRCt*K1'-K1*ESCt'-ESCt*K1';
      // 
   else
    // 
      Hy0 = H*y0;
      if t>1 then
      // 
         K1 = K0+(Phi-K0*H)*y0*M0*Hy0'*iB1;
         if grocer_e4_vcond==1 then
            y1 = (Phi-K0*H)*y0;
            M1 = M0-M0*Hy0'*iB1*Hy0*M0;
         else
            y1 = (Phi-K1*H)*y0;
         
            //! iB0 not defined in the function
            M1 = M0+M0*Hy0'*mtlb(iB0)*Hy0*M0;
         end
         B0 = B1;
         // 
      end
     
      Phib = Phi-K1*H;
      if r then
         x1 = Phi*x0+Gam*z(t,m+1:m+r)'+K1*z1;
      else
         x1 = Phi*x0+K1*z1;
      end
      B1 = B0+H*y1*M1*y1'*H';
    // 
   end
   
   if savessv then
      ssvect(t+1,:) = x1';
   end
   z1U = z1'/U;
   
   if MV|grocer_e4_vcond==4 then
    //   
      HPhi = H*Phibb0;
      WW = WW+HPhi'*iB1*HPhi;
      WZ = WZ+HPhi'*iB1*z1;
      Phibb0 = Phib*Phibb0;
     // 
   end
   
   ff = ff+2*sum(log(diag(U)))+trace(z1U*z1U');
   
   if grocer_e4_filtk then
      P0 = P1;
      x0 = x1;
   else
      K0 = K1;
      x0 = x1;
      y0 = y1;
      M0 = M1;
      iB0 = iB1;
   end
  //   
end
// t
 
if MV|grocer_e4_vcond==4 then
  if or(isnan([WW,WZ]),1)|or(isinf([WW,WZ]),1) then
    e4error(25);
  end
end
 
if grocer_e4_vcond==4 then
  // 
  if ~nonstat then
    // stationary system
    // 
    [M,S,M] = svd(Sigm);
    k = matrix(find(diag(S)<grocer_e4_zeps),1,-1);
    if size(k,1)<l then
      if size(k,1) then
        // 
        M = M(:,1:k(1)-1);
        Sigm = S(1:k(1)-1,1:k(1)-1);
        WW = M'*WW*M;
        WZ = M'*WZ;
        // 
      end
      M = chol(Sigm);
      T = chol(eye(size(M,1),size(M,1))+M*WW*M');
      ff = ff+2*sum(log(diag(T)));
       
      if MV then
        ff = ff-WZ'*pinv(WW,grocer_e4_zeps)*WZ;
      elseif grocer_e4_econd~=2 then
        ff = ff-sum((T'\(M*WZ)).^2);
      end
    end
    // 
  elseif nonstat==2 then
    // non stationary system
    // 
    T = cholp(WW,0);
    ff = ff+2*sum(log(diag(T)))-sum((T'\WZ).^2);
    // 
  else
    // partially stationary
    //  
    S = svd(Sigm);
    T = cholp(iSigm+WW,0);
    ff = ff+2*sum(log(diag(T)))+sum(log(S(S>grocer_e4_zeps)));
     
    if grocer_e4_econd==2 then
      T = cholp(WW,0);
    end
    ff = ff-sum((T'\WZ).^2);
    // 
  end
  // 
elseif MV then
  ff = ff-WZ'*pinv(WW,grocer_e4_zeps)*WZ;
end
 
f = .5*(ff+n*m*log(2*%pi));
