function [f,g,ind]=lfmod_gmod_103(theta,ind)

// PURPOSE: Computes the exact likelihood function of a general
// State Space model. 
// 103 means:
// - the use of the kalman filter (1)
// - the first value of the exogenous variable for the initial
// conditions (econd=3)
// - the estimate of initial values is not made (MV=0)
// ------------------------------------------------------------
// INPUT:
// * theta = (npx1) vector of intial values for the parameters
// * ind = a flag for optim (see optim for details)
// ------------------------------------------------------------
// OUTPUT:
// * f = a scalar, the function value (minus loglikelihood)
// * g = a (npx1) vector, the gradient of the function
// ------------------------------------------------------------
// Copyright Jaime Terceiro, 1997/
// Eric Dubois 2003 for the Scilab translation and adaptation
 

[Phi,Gam,E,H,D,C,Q,S,R] = theta2ss(theta,grocer_e4_theta2mat);
r = size(Gam,2);
 
if size(grocer_e4_z,2)~=(grocer_e4_m+r) then
  error('Incorrect model');
end

[x00,P00] = lfmodini(Phi,Gam,E,H,D,C,Q,S,R,grocer_e4_z,grocer_e4_MV);
[nk1,nx]=size(x00)
nphi=size(P00,2)
CRCt = C*R*C';
ESCt = E*S*C';
EQEt = E*Q*E';
 
ff = 0;
np = size(theta,1);
g = zeros(np,1);

x0= x00;
P0 = P00;

z1=zeros(grocer_e4_m,grocer_e4_T)
B1_3d=zeros(grocer_e4_m,grocer_e4_m*grocer_e4_T)
iB1_3d=zeros(grocer_e4_m,grocer_e4_m*grocer_e4_T)
x0_3d=ones(1,grocer_e4_T+1).*.x0
P0_3d=ones(1,grocer_e4_T+1).*.P0
K1_3d=zeros(nk1,grocer_e4_m*grocer_e4_T)

for t = 1:grocer_e4_T
   z1(:,t) = grocer_e4_z(t,1:grocer_e4_m)'-H*x0-(D+0)*(grocer_e4_z(t,grocer_e4_m+1:grocer_e4_m+r)'+0);
   B1 = H*P0*H'+CRCt;
   
   U = cholp(B1,grocer_e4_scaleb*abs(B1));
   iB1 = eye(grocer_e4_m,grocer_e4_m)/U/U';
   K1 = (Phi*P0*H'+ESCt)/U/U';
  
   x1 = Phi*x0+(Gam+0)*(grocer_e4_z(t,grocer_e4_m+1:grocer_e4_m+grocer_e4_r)'+0)+K1*z1(:,t);
   Phib = Phi-K1*H;
   P1 = Phib*P0*Phib'+EQEt+K1*CRCt*K1'-K1*ESCt'-ESCt*K1';
    // 
   z1U = z1(:,t)'/U;
     
   ff = ff+2*sum(log(diag(U)))+trace(z1U*z1U');
   
   P0 = P1;
   x0 = x1;
   K1_3d(:,grocer_e4_m*(t-1)+1:grocer_e4_m*t)=K1
   B1_3d(:,grocer_e4_m*(t-1)+1:grocer_e4_m*t)=B1
   iB1_3d(:,grocer_e4_m*(t-1)+1:grocer_e4_m*t) = iB1
   x0_3d(:,nx*t+1:nx*(t+1))=x0
   P0_3d(:,nphi*t+1:nphi*(t+1))=P0
  //   
end
// t

f = .5*(ff+grocer_e4_T*grocer_e4_m*log(2*%pi));
 
for i = 1:np
  // 
   [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dv(theta,grocer_e4_theta2mat,i);
   dx0 = zeros(nphi,1);
   dP0 = zeros(nphi,1);
   [P0,nonstat] = lyapunov(Phi,E*Q*E');
   
   if nonstat>0 then
      if or(dPhi)|or(dE)|or(dQ)|or(dGam) then
          k = 0;
          // numerical difference step
          [ignore,P0] = djccl(Phi,E*Q*E',k);
          [ignore,P1] = djccl(Phi+dPhi*grocer_e4_deps,(E+dE*grocer_e4_deps)*(Q+dQ*grocer_e4_deps)*((E+dE*grocer_e4_deps)'),k);
      end
      dP0 = (P1-P0)/grocer_e4_deps;
   else
      dPhib = dPhi*P0*Phi';
      dQb = dE*Q*E';
      dP0 = lyapunov(Phi,dPhib+dPhib'+dQb+E*dQ*E'+dQb');
   end
    // 
   gg = 0;
   
   dB1_0 = dC*R*C'+C*dR*C'+C*R*dC'
   dK1_0 = dE*S*C'+E*dS*C'+E*S*dC'
   dP1_0 = dE*Q*E'+E*dQ*E'+E*Q*dE'

   for t = 1:grocer_e4_T
      P0=P0_3d(:,nphi*(t-1)+1:nphi*t)
      x0=x0_3d(:,nx*(t-1)+1:nx*t)
      B1=B1_3d(:,grocer_e4_m*(t-1)+1:grocer_e4_m*t)
      iB1=iB1_3d(:,grocer_e4_m*(t-1)+1:grocer_e4_m*t)
      K1=K1_3d(:,grocer_e4_m*(t-1)+1:grocer_e4_m*t)
      Phib = Phi-K1*H;

      dz1 = -dH*x0-H*dx0-(dD+0)*(grocer_e4_z(t,grocer_e4_m+1:grocer_e4_m+r)'+0);
      dB1 = dH*P0*H'+H*dP0*H'+H*P0*dH'+dB1_0
      
      dK1 = (dPhi*P0*H'+Phi*dP0*H'+Phi*P0*dH'+dK1_0-K1*dB1)*iB1;
      dPhib = dPhi-dK1*H-K1*dH;
      dGamb = dGam-dK1*D-K1*dD;
      dx1 = dPhib*x0+Phib*dx0+(dGamb+0)*(grocer_e4_z(t,grocer_e4_m+1:grocer_e4_m+r)'+0)+dK1*grocer_e4_z(t,1:grocer_e4_m)';
      dP1 = dPhib*P0*Phib'+Phib*dP0*Phib'+Phib*P0*dPhib'+dP1_0+...
      dK1*CRCt*K1'+K1*dB1_0*K1'+K1*CRCt*dK1'-dK1*ESCt'-K1*dK1_0'-...
      dK1_0*K1'-ESCt*dK1';
      z1i = z1(:,t)'*iB1;

      gg = gg+.5*trace(iB1*dB1)+z1i*dz1-.5*(z1i*dB1*z1i');
      dP0 = dP1;
      dx0 = dx1;
   // 
   end
   // t
   
   g(i) = gg;
   // 
end
 
