function [theta,theta2mat,thetalab,grocer_X,grocer_indtheta,grocer_ineq]=mat2theta(grocer_namex,grocer_indtheta,grocer_ineq,grocer_sym,grocer_m)

// PURPOSE: transforms a matrix into a vector of parameters
// ------------------------------------------------------------
// INPUT:
// * grocer_namex = a string representing the name of either: 
//   - a (mxn) matrix of constant type
//   - a (mx1) vector representing the diagonal of a matr (mxm)
//     matrix
//   - a list with 2 elements:
//       a (mxn) matrix of constant type
//       a (mxn) matrix of string type of constraints
//   ('' for no constraint, '=' for equality constraint, 
//    'value<*', '*<value' or 'value1<*<value2' for grocer_inequality
//    constraints)
// * grocer_sym = %T if the matrix is grocer_symetric
//         %F if it is not 
// * grocer_ineq = vector of grocer_inequality constraints
// ------------------------------------------------------------
// OUTPUT:
// * theta = a (px1) vector of parameters  
// * theta2mat = a (qx1) vector of strings, representing the
//   instructions that transform back theta into the input
//   matrix
// * theatlab = the names of the elements in the input matrix
//   that will be estimated
// * grocer_X = the (mxn) matrix corresponding to the input
// * grocer_indtheta = p = the # of parameters
// * grocer_ineq = %T if there are some grocer_inequality constraints
//         %F if not 
// ------------------------------------------------------------
// NOTE: used by varma function arma2param
// ------------------------------------------------------------
// Copyright: Eric Dubois 2004


theta=[]
theta2mat=[]
thetalab=[]
grocer_indtheta0=grocer_indtheta

grocer_X=evstr(grocer_namex)
select typeof(grocer_X)
case 'constant' then
// there is no constraint on the coefficient of the matrix
   if grocer_X ~= [] then
   // matrix is not empty
      [nr,nc]=size(grocer_X)
      if nr==1 & nc==1 then
         theta=grocer_X
         theta2mat=[grocer_namex+'=theta('+string(grocer_indtheta+1)+')']
         thetalab=[thetalab ; grocer_namex+' - lag 1']
         grocer_indtheta=grocer_indtheta+1

      elseif grocer_sym then
      // only the lower part of the matrix will be estimated
         if nr==1 | nc==1 then
         // only the diagonal is non zero
            theta=grocer_X
            theta2mat=[grocer_namex+'=diag(theta('+string(grocer_indtheta+1)+':'+..
               string(grocer_indtheta+max(nr,nc))+'))']
            thetalab=[thetalab ; grocer_namex+'('+string([1:max(nr,nc)]')+','+...
                   string([1:max(nr,nc)]')+')']
            grocer_X=diag(grocer_X)
            grocer_indtheta=grocer_indtheta+max(nr,nc)
         else
            theta=vech(grocer_X)
            theta2mat=[grocer_namex+'=invvech(theta('+string(grocer_indtheta+1)+':'+..
               string(grocer_indtheta+nr*(nr+1)/2)+'),'+string(nr)+')']
            thetalab=[thetalab ; vech(grocer_namex+'('+string([1:nr]' .*. ones(1,nc))+','+...
               string(ones(nr,1) .*. [1:nc])+')')]
            grocer_indtheta=grocer_indtheta+nr*(nr+1)/2
         end

      else
      // transforms the matrix into a vector of parameters
         theta=matrix(grocer_X,nr*nc,1)
         theta2mat=[grocer_namex+'=matrix(theta('+string(grocer_indtheta+1)+':'+..
            string(grocer_indtheta+nr*nc)+'),'+string(nr)+','+string(nc)+')']
         if grocer_m == 1 then 
            thetalab=[thetalab ; matrix(grocer_namex+'- lag: '+...
                   string(ones(nr,1) .*. [1:nc])+')',nr*nc,1)]
         else
            nlags=nc/grocer_m
            thetalab=[thetalab ; matrix(grocer_namex+' - eq # '+string([1:grocer_m]' .*. ones(1,nc))+' - lag # '+...
                   string(ones(nr,1) .*. ([1:nc/grocer_m]) .*. ones(1,grocer_m))+' - var # '+...
                   string(ones(nr,1) .*. ([1:grocer_m]) .*. ones(1,nc/grocer_m)),nr*nc,1)]
         end
         grocer_indtheta=grocer_indtheta+nr*nc
      end
      grocer_ineq=[grocer_ineq ; [-%inf  %inf] .*. ones(grocer_indtheta-grocer_indtheta0,1)]
   end

case 'string' then
   grocer_X=stripblanks(grocer_X)
   [ir,ic]=find(part(grocer_X,1) ~= '=')
   indlags=floor((ic-1)/grocer_m)+1
   indvars=ic-(indlags-1)*grocer_m
   // retrieves the indexes of the parameters that are not constrainted
   for i=1:size(ir,2)
      if ~grocer_sym | ir(i)>=ic(i) then
      // if the matrix is supposed to be grocer_symetric, then take into account
      // only the parameters on the lower triangular part of the matrix   
         theta=[theta ; evstr(grocer_X(ir(i),ic(i)))]
         theta2mat=[theta2mat ; grocer_namex+'('+string(ir(i))+','+string(ic(i))+')=theta('+string(grocer_indtheta+1)+')']
         thetalab=[thetalab ; grocer_namex+' - eq # '+string(ir(i))+...
                  ' - lag # '+string(indlags(i))+' - var # '+string(indvars(i))]
         grocer_indtheta=grocer_indtheta+1
      end
   end
   // creates the initial numerical matrix by stripping the '=' signs and
   // transforming the strings into real numbers 
   grocer_X=evstr(strsubst(grocer_X,'=',''))
   grocer_ineq=[grocer_ineq ; [-%inf  %inf] .*. ones(grocer_indtheta-grocer_indtheta0,1)]

case 'list' then
   // separates the list into the matrix of constraints and the one
   // of values
   grocer_XC=stripblanks(grocer_X(2))
   grocer_X=stripblanks(grocer_X(1))
   [nr,nc]=size(grocer_X)
   [ir,ic]=find(part(grocer_X,1) ~= '=')
   // retrieves the indexes of the parameters that are not constrainted
   for i=1:size(ir,2)
      if ~grocer_sym | ir(i)>=ic(i) then
      // if the matrix is supposed to be grocer_symetric, then take into account
      // only the parameters on the lower triangular part of the matrix   
         theta=[theta ; evstr(grocer_X(ir(i),ic(i)))]
         theta2mat=[theta2mat ; grocer_namex+'('+string(ir(i))+','+string(ic(i))+')=theta('+string(grocer_indtheta+1)+')']
         if nr == 1 then
            thetalab=[thetalab ; grocer_namex+' lag # '+string(ic(i))]
         else
            thetalab=[thetalab ; grocer_namex+' - eq # '+string(ir(i))+' - param # '+string(ic(i))]
         end
         grocer_indtheta=grocer_indtheta+1
         xij=grocer_XC(ir(i),ic(i))
         grocer_ineq=[grocer_ineq ; -%inf %inf]
         ind=strindex(xij,'<')
         if ind ~= [] then
            indinf=part(xij,1:ind(1)-1)
            indsup=part(xij,ind($)+1:length(xij))
            if indinf ~= emptystr() then
               grocer_ineq($,1)=evstr(indinf)
            end
            if indsup ~= emptystr() then
               grocer_ineq($,2)=evstr(indsup)
            end
         end
      end
   end
   grocer_X=evstr(strsubst(grocer_X,'=',''))
            
else
   error('type of '+grocer_namex+' should be list or constant, not '+typeof(grocer_X))
end
