function E4OPTION=sete4opt(E4OPTION,o1,v1,o2,v2,o3,v3,o4,v4,o5,v5,o6,v6,o7,v7,o8,v8,o9,v9,o10,v10)

// PURPOSE: Allows user to modify the global E4 toolbox options
// ------------------------------------------------------------
// INPUT:
// * o1,..., o10 = strings, options that can be set by the user
// * v1,..., v10 = the admissible options
// with the following possibilities:
//   oi	                 vi
// filter   kalman, chandrashekhar.
// scale    Matrix scaling during filtering operations: 'yes', 'no'.
// vcond    initial conditions for the variance of the state vector:
//           'lyapunov', 'zero', 'idej' (Inverse De Jong).
// econd    initial conditions for the expectation of the state vector:
//           'ml', 'zero', 'au', 'iu', 'auto'.
// var      optimize with respect to the noise covariances or the
//          corresponding Cholesky factors.
// toler    tolerance for stop criteria.
// maxiter  maximum number of iterations.
// ------------------------------------------------------------
// OUTPUT:
// E4OPTION = the vector of options
// ------------------------------------------------------------
// NOTE: this is -almost- the original program; some options 
// can still be set by the program, but whith no effect on the
// working of the program
// ------------------------------------------------------------
// Copyright (c) Jaime Terceiro, 1997
// Eric Dubois 2003 for the Scilab translation and adaptation

[nargout,nargin] = argn(0)
nargin=nargin-1
nargin2 = nargin;
 
if (nargin2>1)&((nargin2-fix(nargin2./2).*2)~=0)|nargin2>20 then
   error('Incorrect number of arguments');
end
 
if nargin2==0 then
  // Default values
   
  E4OPTION(1) = 1       // Kalman filter
  E4OPTION(2) = 0       // No scaling of B
  E4OPTION(3) = 4       // Inverse De Jong
  E4OPTION(4) = 5       // Automatic selection
  E4OPTION(5) = 0       // Variances
  E4OPTION(6) = 1       // BFGS algorithm
  E4OPTION(7) = .1      // step length
  E4OPTION(8) = .00001  // stop tolerance
  E4OPTION(9) = 75      // Maximum number of iterations
  E4OPTION(10) = 1      // Verbose optimization
  // Options not user modifiable
   
  E4OPTION(11) = .00001       // Box-Cox trans. mimimum value
  E4OPTION(12) = 1-.00001     // Tolerance fo unitary eigenvalues
  E4OPTION(13) = .0000000001  // DJCCL: pseudoinverse tolerance for M
  E4OPTION(14) = .0001        // DJCCL: pseudoinverse tolerance for Q
  E4OPTION(15) = sqrt(%eps)  // pseudoinverse general tolerance (LFMOD)
  E4OPTION(16) = 100000       // LFMODINI: De Jong's k
  E4OPTION(17) = .000001      // FISMOD: pseudoinverse tolerance
   
  opt = E4OPTION;
  disp(' ');
  //  disp('************************ Default values ************************');
  //  disp(' ');
  nargin2 = 1;
  o1 = 'show';
  // Default
end
 
if nargin2==1 then
  if length(o1)<3 then
    error('incorrect option: '+o1);
  end
  if part(o1,1:3)=='sho' then
    //   disp(' '); disp(' ');
    disp('*********************** Options set by user ********************');
    if E4OPTION(1)==1 then
      s1 = 'KALMAN';
    else
      s1 = 'CHANDRASEKHAR';
    end
    if E4OPTION(2)==1 then
      s2 = 'YES';
    else
      s2 = 'NO';
    end
    if E4OPTION(3)==1 then
      s3 = 'LYAPUNOV';
    elseif E4OPTION(3)==2 then
      s3 = 'ZERO';
    elseif E4OPTION(3)==3 then
      s3 = 'DJONG';
    else
      s3 = 'IDEJONG';
    end
    if E4OPTION(4)==1 then
      s4 = 'u0 = EXOGENOUS MEAN';
    elseif E4OPTION(4)==2 then
      s4 = 'MAXIMUM LIKELIHOOD';
    elseif E4OPTION(4)==3 then
      s4 = 'ZERO';
    elseif E4OPTION(4)==4 then
      s4 = 'u0 = EXOGENOUS FIRST VALUE (u1)';
    elseif E4OPTION(4)==5 then
      s4 = 'AUTOMATIC SELECTION';
    end
    if E4OPTION(5)==1 then
      s5 = 'FACTOR';
    else
      s5 = 'VARIANCE';
    end
    if E4OPTION(6)==1 then
      s6 = 'BFGS';
    else
      s1 = 'NEWTON';
    end
    if E4OPTION(10)==1 then
      s10 = 'YES';
    else
      s10 = 'NO';
    end
     
    disp('Filter. . . . . . . . . . . . . : '+s1);
    disp('Scaled B and M matrices . . . . : '+s2);
    disp('Initial state vector. . . . . . : '+s4);
    disp('Initial covariance of state v.  : '+s3);
    disp('Variance or Cholesky factor . : '+s5);
    disp('Optimization algorithm. . . . . : '+s6);
    disp('Maximum step length . . . . . . : '+mtlb_sprintf('%8.6f',E4OPTION(7)));
    disp('Stop tolerance. . . . . . . . . : '+mtlb_sprintf('%8.6f',E4OPTION(8)));
    disp('Max. number of iterations . . . : '+mtlb_sprintf('%8i',E4OPTION(9)));
    disp('Verbose iterations. . . . . . . : '+s10);
    disp('****************************************************************');
    disp(' ');
    disp(' ');
  else
     error('incorrect option: '+o1);

  end
  return
   
end
 
for i = 1:nargin2/2
   optstr = evstr('o'+string(i))
   optval = evstr('v'+string(i))
   if length(optstr)<3 then
      error('Unrecognized option:'+optstr);
   end
   if size(optval,2)<1 then
      error('Unrecognized option:'+optstr);
   end
   if part(optstr,1:3)=='fil' then
      optval = convstr(optval);
      if part(optval,1)=='k' then
         E4OPTION(1) = 1
      elseif part(optval,1)=='c' then
      if E4OPTION(3)==3 then
        error('If vcond=De Jong, filter must be Kalman');
      else
        E4OPTION(1) = 2
      end
    else
      error('Unrecognized value:'+optval);
    end
     
  elseif part(optstr,1:3)=='esc'|part(optstr,1:3)=='sca' then
    optval = convstr(optval);
    if part(optval,1)=='s'|part(optval,1)=='y' then
      E4OPTION(2) = 1
    elseif part(optval,1)=='n' then
      E4OPTION(2) = 0
    else
      error('Unrecognized value:'+optval);
    end
     
  elseif part(optstr,1:3)=='vco' then
    optval = convstr(optval);
    if part(optval,1)=='l' then
       E4OPTION(3) = 1
    elseif part(optval,1)=='c'|part(optval,1)=='z' then
      E4OPTION(3) = 2
      //      elseif optval(1) == 'd' | optval(1) == 'j'
      //         if E4OPTION(1) == 2
      //         e4error(31);
      //      else
      //            E4OPTION(3) = 3;
      //         end
    elseif part(optval,1)=='i' then
      E4OPTION(3) = 4
    else
      error('Unrecognized value:'+optval);
    end
     
     
  elseif part(optstr,1:3)=='eco' then
    optval = convstr(optval);
    if (part(optval,1)=='a')&(size(optval,2)<3) then
       E4OPTION(4) = 1
    elseif part(optval,1)=='m' then
      E4OPTION(4) = 2
    elseif part(optval,1)=='c'|part(optval,1)=='z' then
      E4OPTION(4) = 3
    elseif part(optval,1)=='i' then
      E4OPTION(4) = 4
    elseif part(optval,1:3)=='aut' then
      E4OPTION(4) = 5
    else
      error('Unrecognized value:'+optval);
    end
     
  elseif part(optstr,1:3)=='var' then
    optval = convstr(optval);
    if part(optval,1)=='v' then
      E4OPTION(5) = 0
    elseif part(optval,1)=='f' then
      E4OPTION(5) = 1
    else
    end
     
  elseif part(optstr,1:3)=='alg' then
    optval = convstr(optval);
    if part(optval,1)=='b' then
      E4OPTION(6) = 1
    elseif part(optval,1)=='n' then
      E4OPTION(6) = 2
    else
      error('Unrecognized value:'+optval);
    end
     
  elseif part(optstr,1:3)=='pas'|part(optstr,1:3)=='ste' then
    s4 = mtlb_sprintf('%8.6f',optval);
    if optval>0 then
      E4OPTION(7) = optval
    else
      error('Invalid value for:'+optval);
    end
     
  elseif part(optstr,1:3)=='tol' then
    s4 = mtlb_sprintf('%8.6f',optval);
    if optval>0 then
      E4OPTION(8) = optval
    else
      error('Invalid value for:'+optval);
    end
     
  elseif part(optstr,1:3)=='max' then
    s4 = mtlb_sprintf('%8i',fix(optval));
    if optval>0 then
      E4OPTION(9) = fix(optval)
    else
      error('Invalid value for:'+optval);
    end
     
  elseif part(optstr,1:3)=='ver' then
    optval = convstr(optval);
    if part(optval,1)=='s'|part(optval,1)=='y' then
      E4OPTION(10) = 1
    elseif part(optval,1)=='n' then
      E4OPTION(10) = 0
    else
      error('Unrecognized value:'+optval);
    end
     
  else
      error('Unrecognized option:'+optstr);
  end
end
opt = E4OPTION;
