function [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR]=ss_dv(theta,theta2mat,i)

// PURPOSE: Computes the partial derivatives of the matrices of
// a SS model with respect to the i-th parameter in theta.
// The model is suppose to be written as follows:
//    x(t+1) = Phix(t) + Gamu(t) + Ew(t)
//    y(t)   = Hx(t)   + Du(t)   + Cv(t)
//    V(w(t) v(t)) = [Q S; S' R];
// ------------------------------------------------------------
// INPUT:
// * theta = (npx1) vector of starting values for the
//   parameters
// * theta2mat = a string vector of instructions that
//   transforms theta into the matrices FR, FS, AR, AS, V and G
// * i = a scalar
// ------------------------------------------------------------
// OUTPUT:
// dPhi, dGam, dE, dH,dD,dC,dQ,dS,dR = the derivatives of the
// corresponding matrices (that is unprefixed by d) with
// respect to the i-th parameter in theta.
// ------------------------------------------------------------
// NOTE:
// This function does not work with composite models.
// ------------------------------------------------------------
// Copyright Jaime Terceiro, 1997/
// Eric Dubois 2003 for the Scilab translation
 
if grocer_e4_userflag then
  if userflag<2 then
    error('User function not defined for the analytic gradient');
  end
  [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dvown(theta,theta2mat,i,userf(2,:));
  return
   
end
 
if grocer_e4_type<4 then
  // simple model
  [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dvs(theta,theta2mat,i);
  return
   
end
 
if grocer_e4_type==4 then
  // echelon
  [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dvh(theta,theta2mat,i);
  return
   
end
 
if grocer_e4_type==7 then
  [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dvss(theta,theta2mat,i);
  return
   
end
 
if fix(grocer_e4_type/10)==2 then
  // nested
  [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dvn(theta,theta2mat,i);
  return
   
end
 
if fix(grocer_e4_type/10)==3 then
  // components
  [dPhi,dGam,dE,dH,dD,dC,dQ,dS,dR] = ss_dvc(theta,theta2mat,i);
  return
   
end
 
error('Invalid model');
