function [hpy]=hpfilter(y,lambda)

// PURPOSE: Hodrick Prescott filter
// ------------------------------------------------------------
// INPUT:
// * y = either 
//   . a time series, or
//   . a real (nx1) vector, or 
//   . a string equal to the name of a time series or a (nx1) 
//     real vector between quotes
// * lamanda = the smoothing parameter
// ------------------------------------------------------------
// OUTPUT:
// hpy= the smoothed filtered series of the same type than y 
// (if y is not a string) or evstr(y) (if y is a string) 
// ------------------------------------------------------------
// Copyright Eric Dubois 2002
// adapted from:
// Ivailo Izvorski, 
//          Department of Economics
//          Yale University.
//          izvorski@econ.yale.edu

prests=%f
select typeof(y)
case 'ts' then
   prests=%t
   if exists('grocer_boundsvar') then
      if size(grocer_boundsvar,1) > 2 then
         write(%io(2),'bounds are: ['''+joinstr(grocer_boundsvar,''';''')+''']')
         error('discontinous bounds are not allowed in hpfilter')
      else
         s=ts2vec(y,grocer_boundsvar)
      end
   else
      s=y('series')
   end
case 'constant' then
   if size(y,1)==1 then
      s=y'
   elseif size(y,2)==1 then
      s=y
   else
      error('a matrix of size ['+string(size(y,1))+...
      ' ; '+string(size(y,2))+'] is not a avalid first entry for hpfilter')
   end
else 
   error(string(typeof(y))+' is not a valid type for hpfilter ...
   first entry')
end
 
t = size(s,1);
a = 6*lambda+1;
b = -4*lambda;
c = lambda;
d = [c,b,a];
d = ones(t,1)*d;
m = diag(d(:,3))+diag(d(1:t-1,2),1)+diag(d(1:t-1,2),-1);
m = m+diag(d(1:t-2,1),2)+diag(d(1:t-2,1),-2);
 
m(1,1) = 1+lambda;
m(1,2) = -2*lambda;
m(2,1) = -2*lambda;
m(2,2) = 5*lambda+1;
m(t-1,t-1) = 5*lambda+1;
m(t-1,t) = -2*lambda;
m(t,t-1) = -2*lambda;
m(t,t) = 1+lambda;
 
s = inv(m)*s;
 
if prests then
   if exists('grocer_boundsvar') then
      hpy=reshape(s,grocer_boundsvar(1))
   else
      hpy=y
      hpy('series')=s
   end
else
   hpy=s
end
