function [grocer_lx,grocer_listcoef,grocer_ncoefeqs,grocer_xx,grocer_namexos,grocer_boundsvarb]=syslist(grocer_l,coef,grocer_boundsvarb)

// PURPOSE: explode a list of equations into the lists of 
// variables, coefficients, their index in each equation,
// value of endogenous variables, name of exogenous
// variables and, if necessary, updates the bounds
// ------------------------------------------------------------
// INPUT:
// strings which can be:
// * 'niter=x' where x is the max # iterations authorized 
//   (optional; default =100)   
// * 'crit=x' where x is the convergence criterion
//   (optional; default =1e-4)
// * 'coef=xx' wher xx is a vector of coefficients names
// * equations written 'vary=coef1*varx1+...+coefi*varxi' 
//   where:
//   - coefi = the name of a coefficient   
//   - varxi = the name of a variable  
// * 'noprint' if the user does not want to print the results
// ------------------------------------------------------------
// OUTPUT:
// rsur=a tlist with
// - rsur('meth') = 'sur'
// - rsur('nobs') = # of observations
// - rsur('neqs') = # of estimated equations
// - rsur('ncoef') = # of estimated coefficients
// - rsur('beta') = bhat
// - rsur('tstat') = t-stats
// - rsur('pvalue') = pvalue of the betas
// - rsur('sigma') = covariance matrix of the residuals
// - rsur('sigu') = (1 x neqs) sum of squared residuals
// - rsur('sigu') = (1 x neqs) sum of squared residuals
// - rsur('dw') = (1 x neqs) Durbin-Watson
// - rsur('prests') = boolean indicating the presence or
//     absence of a time series in the regression
// - rsur('namecoef') = (ncoef x 1) mame of the coeffcients
// - rsur('namey') = name of endogenous variables
// - rsur('eqs') = list of the neqs equations
// - rsur('coefs') = list of the coefs names in each equation
// ------------------------------------------------------------
// NOTES:
// * some coefficients can be commun to several equations
// * there can be spaces in the text of the equations
// * if you want to introduce a constant in your equation, you
//   can omit the '*varxi' in the text of the equation
// * the exogenous variable can be expressed anyway ; however,
//   you must respect the syntax 
//   'vary=coef1*varx1+...+coefi*varxi'
//  for instance, you cannot write:
// 'vary=(coef1+coef2)*varx1...'
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002  

grocer_neqs=length(grocer_l)
// create a list with the endogenous and exogenous variables
// and the list of coefficients for each equation

// first the endogneous variables
grocer_chx='grocer_lx=list('
for grocer_i=1:grocer_neqs
   grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),' ','')
   grocer_chx=grocer_chx+part(grocer_l(grocer_i),1:strindex(grocer_l(grocer_i),'=')-1)+','
end
grocer_chx=part(grocer_chx,1:length(grocer_chx)-1)
grocer_listcoef=list()
grocer_ncoefeqs=zeros(grocer_neqs,1)

// next the exogenous variables
for grocer_i=1:grocer_neqs
   grocer_ch='grocer_ncoef'+string(grocer_i)+'=[]'
   execstr(grocer_ch)
   grocer_l(grocer_i)=part(grocer_l(grocer_i),strindex(grocer_l(grocer_i),'='):...
                   length(grocer_l(grocer_i)))
   for grocer_j=1:grocer_ncoef
      if strindex(grocer_l(grocer_i),coef(grocer_j)) == ...
      length(grocer_l(grocer_i))-length(coef(grocer_j))+1 then
         stri=strindex(grocer_l(grocer_i),coef(grocer_j))
      else
         stri=strindex(grocer_l(grocer_i),coef(grocer_j)+'*')+...
           strindex(grocer_l(grocer_i),coef(grocer_j)+'+')+...
           strindex(grocer_l(grocer_i),coef(grocer_j)+'-')
      end
      if size(stri,1) ~= 0 then
         grocer_ch='grocer_ncoef'+string(grocer_i)+'=[grocer_ncoef'+string(grocer_i)+';...
                '+string(grocer_j)+']'
         execstr(grocer_ch)
         if part(grocer_l(grocer_i),stri+length(coef(grocer_j))) == '*' then
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'=+'+coef(grocer_j)+'*',',')
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'=-'+coef(grocer_j)+'*',',')
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'+'+coef(grocer_j)+'*',',')
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'-'+coef(grocer_j)+'*',',')
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'='+coef(grocer_j)+'*',',')
         else
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'+'+coef(grocer_j),',un')
            grocer_l(grocer_i)=strsubst(grocer_l(grocer_i),'-'+coef(grocer_j),',-un')
         end 
      end
   end
   grocer_chx=grocer_chx+grocer_l(grocer_i)
   grocer_listcoef($+1)=evstr('grocer_ncoef'+string(grocer_i))
   grocer_ncoefeqs(grocer_i)=size(grocer_listcoef($),1)
end
grocer_chx=grocer_chx+')'
execstr(grocer_chx)

[grocer_xx,grocer_namexos,grocer_boundsvarb]=explox(grocer_lx,'exogenous',grocer_boundsvarb)
