function [grocer_g]=numz0(grocer_namefunc,grocer_param,grocer_k,grocer_g,grocer_delta,varargin)

// PURPOSE: calculate a numerical derivative of function
// namefunc at point param
// ------------------------------------------------------------
// INPUT:
// * grocer_namefunc = name of function namefunc with the parameters
//   as first argument
// * grocer_param = point where the derivative is calculated
// * grocer_k = dimension of param
// * grocer_g = a pre-determinated matrix with dimension (k,n) where n
//   is the dimension of namefunc
// * grocer_delta = the Increment used to evaluate the derivative
// * varargin = the arguments other than param in function
//   namefunc  
// ------------------------------------------------------------
// OUPTUT:
//  * grocer_g = numerical derivative
// ------------------------------------------------------------
// NOTES:
// * used by the following functions:
//   nls(), maxlik()
// * the speediest (I think !) possible in scilab
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
// adapted from:
// Mike Cliff,  UNC Finance   mcliff@unc.edu


grocer_id=grocer_delta*eye(grocer_k,grocer_k)
for grocer_i=1:grocer_k
   grocer_g(grocer_i,:)=(grocer_namefunc(grocer_param+...
      grocer_id(:,grocer_i),varargin(:))-...
      grocer_namefunc(grocer_param-grocer_id(:,grocer_i),...
      varargin(:)))'/2/grocer_delta
end
