function []=pltuniv(res,options)

// PURPOSE: plots the results of least-squares regression 
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a univariate regression 
// * options = 'res', 'fitted', or 'all' according to the 
//   results that the user wants to graph (default: all)
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are plotted
// ------------------------------------------------------------
// NOTES:
// * used by the following functions:
// ols(), olsc(), ridge(), automatic()
// * specified for black and white screens or printers
// if you have a color screen or/and a color printer
// put the lines xset("use color", 0) into comment
// ------------------------------------------------------------
// Copyright: Eric Dubois 

[nargout,nargin]=argn(0)

resid=%f
fitted=%f
if nargin == 1 then
   resid=%t
   fitted=%t
else
   select options
   case 'res' 
      resid=%t
   case 'fitted'
      fitted=%t
   case 'all'
      resid=%t
      fitted=%t
   else
      error('invalid option in pltuniv')
   end
end

namex=res('namex')
nobs=res('nobs')
residual=res('resid')
namexp=namex(1)
for i=2:size(namex,1)
   namexp=namexp+', '+namex(i)
end

// if there are ts in the regression, set the values of the x
// axis:
if res('prests') then
   bo=res('bounds')
   for i=1:size(bo,1)/2
      d1=date2num(bo(i*2-1))
      xscale0=num2date([d1:d1+diff_date(bo(2*i),...
              bo(2*i-1))],date2fq(bo(i*2-1)))
   end
else
   xscale0 = [1:nobs]
end


i=1
if resid then
   tit='residuals of the '+res('meth')+' regression of '...
        +res('namey')+' on '+namexp
   pltseries0(residual,0,tit,string(xscale0),i,'x0(1)=0','styleg=4','bars=1','color=5')
end

if fitted then
// open a new window:
   i=i+1
   tit='observed and fitted values of the '+res('meth')+' regression of '...
        +res('namey')+' on '+namexp
   y=[res('y') res('yhat')]
   pltseries0(y,[],tit,string(xscale0),i,'leg=[observed;fitted]','styleg=4')
end
