function []=prtjohan(res,out)

// PURPOSE: prints the results of a Johansen cointegration test 
// on the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a johansen regression 
// * out = the symobolic name of the file where the 
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following function:
// johansen()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002

[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end

lr1=res('lr1')
cvm=res('cvm')
cvt=res('cvt')
nvar=res('nvar')
 
write(out,' ')
write(%io(2),'Johansen estimation results for variables:')
write(%io(2),joinstr(res('namey'),', '))
write(%io(2),'time order: '+string(res('trend')))
write(%io(2),'# of lags: '+string(res('nlags')))

write(out,' ')

mat2prt=['NULL:   ' 'Trace Statistic' 'Crit 90%' ...
         'Crit 95% ' 'Crit 99% ']
for i=1:nvar
   mat2prt=[mat2prt ; 'r <= '+string(i-1) ...
           string(lr1(i)) string(cvt(i,:)) ]
end
printmat(mat2prt,out)

write(out,' ')
write(out,'conclusions from the trace statistics:')

nrel=0
while nrel<nvar-1 & lr1(nrel+1,1) > cvt(nrel+1,1) then
   nrel=nrel+1
end
if lr1(nvar,1) > cvt(nvar,1) then
   nrel=nvar
end
write(out,'at a 10% level, there are '+string(nrel)+' cointegration relation(s)') 

nrel=0
while nrel<nvar-1 & lr1(nrel+1) > cvt(nrel+1,2) then
   nrel=nrel+1
end
if lr1(nvar) > cvt(nvar,2) then
   nrel=nvar
end
write(out,'at a 5% level, there are '+string(nrel)+' cointegration relation(s)') 

nrel=0
while nrel<nvar-1 & lr1(nrel+1) > cvt(nrel+1,3) then
   nrel=nrel+1
end
if lr1(nvar) > cvt(nvar,3) then
   nrel=nvar
end
write(out,'at a 1% level, there are '+string(nrel)+' cointegration relation(s)') 


write(out,' ')

mat2prt=['NULL:   ' 'Max Eigenvalues Statistic ' 'Crit 90% ' ...
         'Crit 95% ' 'Crit 99% ']
for i=1:nvar
   mat2prt=[mat2prt ; 'l <= '+string(i-1)  string(res('lr2')(i)) ...
            string(cvm(i,:)) ]
end
printmat(mat2prt,out)

write(out,' ')
write(out,'conclusions from the maximal eigenvalues statistics:')
nrel=0
while nrel<nvar-1 & lr2(nrel+1,1) > cvm(nrel+1,1) then
   nrel=nrel+1
end
if lr2(nvar,1) > cvm(nvar,1) then
   nrel=nvar
end
write(out,'at a 10% level, there are '+string(nrel)+' cointegration relation(s)') 

nrel=0
while nrel<nvar-1 & lr2(nrel+1) > cvm(nrel+1,2) then
   nrel=nrel+1
end
if lr2(nvar) > cvm(nvar,2) then
   nrel=nvar
end
write(out,'at a 5% level, there are '+string(nrel)+' cointegration relation(s)') 

nrel=0
while nrel<nvar-1 & lr2(nrel+1) > cvm(nrel+1,3) then
   nrel=nrel+1
end
if lr2(nvar) > cvm(nvar,3) then
   nrel=nvar
end
write(out,'at a 1% level, there are '+string(nrel)+' cointegration relation(s)') 


printsep(out)
