function []=prtres(res,out)

// PURPOSE: prints the results of a regression on the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a univariate regression 
// * out = the symobolic name of the file where the 
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following functions:
// ols(), olsc(), ridge(), automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002

[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end

meth=res('meth') 
if or(meth== ['ols';'olst';'olsc';'olsar1';'nls';...
   'iv';'logit';'probit';'tobit';'Theil-Goldberger'...
   'hwhite';'lad';'ridge';'robust']) then
// a case would be better, but I have not found how to use
// case with sets of chars
   prtuniv(res,out)
elseif or(meth == ['sur';'twosls';'threesls']) then
   prtsys(res,out)
elseif or(meth == ['var';'bvar';'ecm';'becm']) then
   prtvar(res,out)
elseif or(meth == ['adf';'kpss';'phillips-perron';...
'Schmidt-Phillips'])
   prtunitr(res,out)
elseif or(meth == ['archtest';'resular';'predfailin';'white'])
   prtchi(res,out)
   prtfish(res,out)
elseif or(meth == ['doornhans';'jbnorm';'chowtest';'reset';'predfail'])
   prtchi(res,out)
elseif or(meth == ['bpagan';'hetero_sq'])
   prtfish(res,out)
elseif meth == 'bkw'
   plt_dfb(results)
   plt_dff(results)
elseif meth == 'tvp'
   prttvp(res)
elseif meth == 'auto'
   prtauto(res,list(),out)
elseif meth == 'johansen'
   prtjohan(res,out)
elseif meth == 'varma'
   prtvarma(res,out)
end
