function prtunitr(res,out)

// PURPOSE: prints the results of unit root tests on the file
// out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a univariate regression 
// * out = the symobolic name of the file where the 
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUTPUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
 
[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end

if res('meth') == 'ADF' then 

   crit1=[res('1% level') res('5% level') res('10% level') ]
   testv1=res('tstat')(1)-crit1
   test0='a unit root'
   prtuniv(res,out)
   write(out,' ')
   write(out,'............................................')
   write(out,' t-value for variable '+res('namex')(1)+...
        ' should be compared to the following values:')
   mat2print =['1% level' '5% level' '10% level' ; string(crit1)]

elseif res('meth') == 'cadf' then 

   crit1=[res('1% level') res('5% level') res('10% level') ]
   testv1=res('tstat')(1)-crit1
   test0='no cointegration'
   prtuniv(res,out)
   write(out,' ')
   write(%io(2),' t-value for variable '+res('namex')(1)+': '+string(rescadf('tstat')(1)))
   write(%io(2),'should be compared to the following values:')
   mat2print =['1% level' '5% level' '10% level' ; string(crit1)]

elseif res('meth') == 'kpss' then

   crit1=[res('1% level') res('5% level') res('10% level') ]
   testv1=crit1-res('test_value')
   test0='stationarity'
   write(out,' ')
   write(out,'KPSS stationarity test for variable: '+res('namey'))
   select res('p')
   case 0 then
      write(out,'with a constant term')
   case 1 then
      write(out,'with a time term')
   end
   if prests then 
      ch='and estimation period: '
      for i=1:size(boundsvarb,1)/2
         ch=ch+boundsvarb(2*i-1)+'-'+boundsvarb(2*i)+'  '
      end
      write(out,ch)
   end

   write(out,'is equal to: '+string(res('test_value')))
   write(out,'this values should be compared to the following ...
              critical values:')
   mat2print =['1% level' '5% level' '10% level' ; string(crit1)]

elseif res('meth') == 'phillips-perron' | ...
  res('meth') == 'Schmidt-Phillips' then
   crit1=[res('cv_rho_1%') res('cv_rho_5%') res('cv_rho_10%') ]
   testv1=res('rho')-crit1
   test0='a unit root'
   write(out,' ')
   write(out,res('meth')+' unit root test for variable: '+res('namey'))
   select res('p')
   case 0 then
      write(out,'with a constant term')
   else
      write(out,'with a time term of order '+string(res('p')))
   end
   if prests then 
      ch='and estimation period: '
      for i=1:size(boundsvarb,1)/2
         ch=ch+boundsvarb(2*i-1)+'-'+boundsvarb(2*i)+'  '
      end
      write(out,ch)
   end
   mat2print =['1% level' '5% level' '10% level' ; string(crit1)]
   write(out,'rho test is equal to: '+string(res('rho')))
   write(out,' ')
   write(out,'this values should be compared to the following ...
              critical values:')

end

printmat(mat2print,out)
write(out,' ')

if testv1(1) < 0 then
   write(out,'conclusion: the null hypothesis of '+test0+' is ...
   rejected at a 1% level')
elseif testv1(2) < 0 then
   write(out,'conclusion: the null hypothesis of '+test0+' is ...
   accepted at a 1% level, but rejected at a 5% level')
elseif testv1(3) < 0 then
   write(out,'conclusion: the null hypothesis of '+test0+' is ...
   accepted at a 5% level, but rejected at a 10% level')
else
   write(out,'conclusion: the null hypothesis of '+test0+' is ...
   accepted at a 10% level')
end

   
if res('meth') == 'schmiphi' | res('meth') == 'phillips-perron' then
   crit2=[res('cv_tstat_1%') res('cv_tstat_5%') res('cv_tstat_10%') ]
   testv2=res('tstat')-crit2
   write(out,' ')
   write(out,'tstat test is equal to: '+string(res('tstat')))
   write(out,' ')
   write(out,'this values should be compared to the following ...
            critical values:')
   mat2print =['1% level' '5% level' '10% level' ; string(crit2)]
   printmat(mat2print,out)
   write(out,' ')

   if testv2(1) < 0 then
      write(out,'conclusion: the null hypothesis of '+test0+' is ...
      rejected at a 1% level')
   elseif testv2(2) < 0 then
      write(out,'conclusion: the null hypothesis of '+test0+' is ...
       accepted at a 1% level, but rejected at a 5% level')
   elseif testv2(3) < 0 then
      write(out,'conclusion: the null hypothesis of '+test0+' is ...
      accepted at a 5% level, but rejected at a 10% level')
   else
      write(out,'conclusion: the null hypothesis of '+test0+' is ...
      accepted at a 10% level')
   end
end

printsep(out)
