function []=prtuniv(res,out)

// PURPOSE: prints the results of least-squares regression on 
// the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a univariate regression 
// * out = the symobolic name of the file where the 
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following functions:
// ols(), olsc(), ridge(), automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002

[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end
 
write(out,' ')
select res('meth')
case 'nls' then
   write(out,res('meth')+' estimation results for equation:')
   write(out,res('namey'))
case 'cadf' then
   res('pvalue') = string(res('pvalue'))
   res('pvalue')(1) = ''
   r1=res('cointrel')
   namex=r1('namex')
   namexp=namex(1)
   for i=2:size(namex,2)
      namexp=namexp+', '+namex(i)
   end
   write(out,'cadf estimation results for second stage ...
   regression of: '+r1('namey'))
   write(out,'on: '+namexp)
   write(out,'res = residuals from first stage regression')
   write(out,' ')
else
   write(out,res('meth')+' estimation results for dependent ...
   variable: '+res('namey'))
end

if res('meth') == 'twosls' | res('meth') == 'threesls' ...
| res('meth') == 'iv' then
   write(out,' ')
   if max(size(res('nameendo'))) == 0 then
      if res('meth') == 'threesls' then
         write(out,'there is no endogenous variable in the equation')
      else
         write(out,'there is no endogenous variable in the equation: iv=ols')
      end
   else
      write(out,'endogenous variable(s) in this equation is(are):')
      write(out,joinstr(res('nameendo'),','))
      write(out,' ')
      write(out,'instruments for this equation are:')
      write(out,joinstr(res('nameinst'),','))
   end
   write(out,' ')
end

if res('prests') then 
   ch='estimation period: '
   boundsvar=res('bounds')
   for i=1:size(boundsvar,1)/2
      ch=ch+boundsvar(2*i-1)+'-'+boundsvar(2*i)+'  '
   end
   write(out,ch)
end

write(out,'number of observations: '+string(res('nobs')))
write(out,'number of variables: '+string(res('nvar')))
if res('meth') == 'logit' | res('meth') == 'probit' then
   write(out,'McFadden R = '+string(res('r2mf')))  
   write(out,'Estrella R = '+string(res('rsqr')))
   write(out,'log-likelihood = '+string(res('like')))
   write(out,'LR-ratio = 2*(Lu-Lr) = '+string(res('lratio')))
   write(out,'LR p-value  = '+string(1-cdfchi("PQ",...
   res('lratio'),res('nvar')-1)))
else
   if res('prescte') then
      write(out,'R = '+string(res('rsqr'))+'      ...
      ajusted R ='+string(res('rbar')))
      if res('meth') == 'twosls' | res('meth') == 'threesls' ...
         | res('meth') == 'iv'  then
         write(out,'generalized R = '+string(res('grsqr'))+' (*)')
      else
         fi="Overall F test: F("+string(res('nvar')-1)+","+...
         string(res('nobs')-res('nvar'))...
         +") = "+string(res('f'))+"       p-value = "+...
         string(res('pvaluef'))
         write(out,fi)
      end
   end
   write(out,'standard error of the regression: '+...
   string(res('ser')))
   write(out,'sum of squared residuals: '+string(res('sigu')))
   write(out,'DW(0) ='+string(res('dw')))
   if res('meth') ~= 'nls' then
      write(out,'Belsley, Kuh, Welsch Condition index: '+...
      string(res('condindex')))
   end
end

if res('meth') == 'garch' then
   write(%io(2),'log likelihood: '+string(like))
   write(out,[' '])
end

if res('meth') == 'Theil-Goldberger' then
   write(out,[' '])
   mat2print=['Prior Mean' 'Std Deviation';...
              string(res('pmean')) string(res('pstd'))]
   printmat(mat2print,out)
   write(out,[' '])
end

write(out,[' '])
mat2print=['variable' 'coeff' 't-statistic' 'p value']
for i=1:res('nvar')
   mat2print=[mat2print ; res('namex')(i) ...
   string(res('beta')(i)) string(res('tstat')(i)) ...
   string(res('pvalue')(i))]
end

if res('meth') == 'ADF' then
   mat2print(2,4) = ''
end
printmat(mat2print,out)

if res('meth') == 'garch' then
   if res('prests') then
      b='bounds=['+joinstr('''',res('bounds'),''';')+''']'
      pltseries('sigt',b,'title=estimated variance of residuals','noleg')
   else
      pltseries('sigt','title=estimated variance of residuals','noleg')
   end   
end

write(out,[' '])
if res('meth') == 'twosls' | res('meth') == 'threesls' ...
   | res('meth') == 'iv'  then
   write(out,'* warning, R and ajusted R are shown here to conform to ...
         commun practice, but only the generalized R should be interpreted')
end

printsep(out)
