function []=prtvarf(rvarf,out)

// PURPOSE: prints the results of a var forecast on 
// the file out
// ------------------------------------------------------------
// INPUT:
// * rvarf = the results typed list of a johansen regression 
// * out = the symobolic name of the file where the 
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following function:
// varf()
// ---------------------------------------------------
// Copyright Eric Dubois 2002
 
[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end

hprev=rvarf('hprev')
rvar=rvarf('rvar')
if rvar('meth') == 'ecm' | rvar('meth') == 'becm' then
// retrieve the true names of the variables
   namey=strsubst(rvar('namey'),'del(','')
   for i=1:rvar('neqs')
      namey(i)=part(namey(i),1:length(namey(i))-1)
   end
else
   namey=rvar('namey')
end

write(out,' ')
if typeof(hprev) == 'string' then
   title='forecasting results for the VAR '+...
   rvarf('namevar')+' over the period '+...
   hprev(1)+'-'+hprev(2)
else
   title='forecasting results for the VAR '+...
   rvarf('namevar')+' at a ['+...
   string(hprev(1))+';'+string(hprev(2))+'] horizon'
end
write(out,title)
stars=emptystr()
for i=1:length(title)
   stars=stars+'*'
end
write(out,stars)
write(out,' ')

if rvar('prests') then
   obs=['obs\variable' ; num2date(rvarf($)('dates'),rvarf($)('freq'))]
else
   obs=['obs\variable' ; string([hprev(1):hprev(2)]')]
end
mat2print=[namey' ; string(rvarf('prev'))]
mat2print=[obs mat2print]
printmat(mat2print,out)
printsep(out)
