function []=prtvarma(results,out)

// PURPOSE: prints the results of a ARMA or VARMA estimation on
// the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a Varma regression 
// * out = the symobolic name of the file where the 
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following functions:
// varma()
// ------------------------------------------------------------
// Copyright (c) Eric Dubois 2004

[nargout,nargin]=argn(0)
if nargin == 1 then
   out=%io(2)
end
 
theta=results('coeff')
labtheta=results('lab')
y=results('y')
[nobs,nvar]=size(y)
fval=results('like')
g=results('grad')
std=results('std')
tstat=results('tstat')
corrm=results('cov')
k=results('nvar')
Y2print = results('namey')
nendo=size(Y2print,1)

mod=''
if or(part(labtheta,1:3)=='AR ') then
   mod=mod+'(1+AR(L))*'
end
if or(part(labtheta,1:3) == 'ARS') then
   mod=mod+'(1+ARS(L^'+string(results('seas'))+')) * '
end
mod=mod+'Y = '
if or(part(labtheta,1:3) == 'MA ') then
   mod=mod+'(1+MA(L))*'
end
if or(part(labtheta,1:3) == 'MAS') then
   mod=mod+'(1+MAS(L^'+string(results('seas'))+')) * '
end
mod=mod+'e'

if results('nexo') then
   namexos=results('namexos')
   nexos=size(namexos,1)
   if results('lagexo') == 0 then
      mod=mod+'+ G*'
   else
      mod=mod+'+ G(L)*'
   end
   if nexos == 1 then
      mod = mod+ namexos
   else 
      mod=mod+'['+joinstr(namexos,' , ')+']'''
   end
end
 
write(out,' ');
if nvar == 1 then 
   write(out,'*************** ARMA estimation Results for model: ***************');
else 
   write(out,'*************** VARMA estimation Results for model: ***************');
end
write(out,mod)
write(out,'with:')
if nendo > 1 then 
   Y2print=[emptystr(nendo,1)+'      [' Y2print emptystr(nendo,1)+' ]' ]
   Y2print(floor(nendo/2)+1,1) = '- Y = [' 
   printmat(Y2print,out)
else 
   write(out,'- Y = '+Y2print)
end
write(out,'- V(e) = V')

write(out,' ');
write(out,'Log-likelihood: '+string(fval));
write(out,'Information criteria: AIC = '+string(results('AIC'))+', BIC = '+string(results('BIC')))
write(out,' ');
if results('exact') then
   mat2print = ['Parameter' 'Estimate'  'Std. Dev.'       't-test' ; ..
   labtheta string([theta std tstat])]
else
   mat2print = ['Parameter' 'Estimate'  'Appr.Std.Dev.'       't-test' ; ..
   labtheta string([theta std tstat])]
end

printmat(mat2print,out)
 
write(out,' ');
if k>1 then
  write(out,'************************* Correlation matrix **************************');
  nbcor=size(corrm,1)
  mat2print=[labtheta emptystr(nbcor,nbcor)]
  for i = 1:nbcor
     mat2print(i,2:i+1)=string(corrm(i,1:i))
  end
  printmat(mat2print,out)
  write(out,' ');
  write(out,'           Condition number = '+ string(cond(corrm)));
  write(out,'Reciprocal condition number = '+ string(rcond(corrm)));
end
write(out,'***********************************************************************');
write(out,' ');
