function [rols]=ols(grocer_namey0,varargin)

// PURPOSE: the most general function performing least-squares
// regression 
// ------------------------------------------------------------
// INPUT:
// * grocer_namey0 = a time series, a real (nx1) vector or a  
// string equal to the name of a time series or a (nx1) real
// vector between quotes
// * varargin = arguments which can be:
//   . a time series
//   . a real (nxp) vector 
//   . a string equal to the name of a time series or a (nxp) 
//     real vector between quotes
//   . the string 'noprint' if the user doesn't want to print
//     the results of the regression
// ------------------------------------------------------------
// OUTPUT: 
// rols = a results tlist with
//   . rols('meth')  = 'ols'
//   . rols('y')     = y data vector
//   . rols('x')     = x data matrix
//   . rols('nobs')  = # observations
//   . rols('nvar')  = # variables
//   . rols('beta')  = bhat
//   . rols('yhat')  = yhat
//   . rols('resid') = residuals
//   . rols('vcovar') = estimated variance-covariance matrix of
//     beta
//   . rols('sige')  = estimated variance of the residuals
//   . rols('sigu')  = sum of squared residuals
//   . rols('ser')  = standard error of the regression
//   . rols('tstat') = t-stats
//   . rols('pvalue') = pvalue of the betas
//   . rols('dw')    = Durbin-Watson Statistic
//   . rols('condindex') = multicolinearity cond index
//   . rols('prescte') = boolean indicating the presence or
//     absence of a constant in the regression
//   . rols('rsqr')  = rsquared
//   . rols('rbar')  = rbar-squared
//   . rols('f')    = F-stat for the nullity of coefficients
//     other than the constant
//   . rols('pvaluef') = its significance level
//   . rols('prests') = boolean indicating the presence or
//     absence of a time series in the regression
//   . rols('namey') = name of the y variable
//   . rols('namex') = name of the x variables
//   . rols('bounds') = if there is a timeseries in the 
//     regression, the bounds of the regression
//   . rols('like') = log-likelihood of the regression
// ------------------------------------------------------------
// PRINTS: If the user has not given the argument 'noprint',
// the results of the regression and various diagnostics
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002

// separate from the list of variable arguments the list of
// exogenous variables and 'noprint' if the user has given this
// argument
grocer_lx=varargin
[grocer_lx,grocer_lnp]=explolist(grocer_lx,...
list('grocer_lx(i)==''noprint'''))

[grocer_y,grocer_namey,grocer_x,grocer_namexos,grocer_prests,grocer_boundsvarb]=explouniv(grocer_namey0,grocer_lx)

// provides the results from the regression of the vector y
// on the vector x
rols=ols2(grocer_y,grocer_x)

// saves the names, the bounds if the regression involves ts
rols(1)($+1) = 'prests'
rols(1)($+1) = 'namex'
rols(1)($+1) = 'namey'
rols('prests')=grocer_prests
rols('namex')=grocer_namexos
rols('namey')=grocer_namey

if grocer_prests then
   rols(1)($+1) = 'bounds'
   rols('bounds')=grocer_boundsvarb
end

if length(grocer_lnp) == 0 then
// the user has not entered 'noprint' as an argument
// a command to activate if foutput has been previously definded:
// prtuniv(rols,foutput)
   prtuniv(rols,%io(2))
   pltuniv(rols,'all')
end
