function ts=%ts_cumprod(ts)

// PURPOSE: computes the cumulative product of a time series
// from the first value non NA until the following NA value or
// the end of the series
// ------------------------------------------------------------
// INPUT:
// * ts = a timeseries
// ------------------------------------------------------------
// OUTPUT:
// * ts = the time series, cumulative product, over the period 
// from the first value non NA until the following NA value or
// the end of the series, of the original timeseries
// ------------------------------------------------------------
// NOTES: 
// ------------------------------------------------------------
// Copyright: Eric Dubois

s=ts('series')


indnonna=find(~isnan(s))
if indnonna == [] then
   warning('input series has only NA values')
else
   firstnonna=indnonna(1)
   delnonna=indnonna-[firstnonna:firstnonna-1+size(indnonna,2)]
   consnonna=find(delnonna==0)
   lastnonna=consnonna(size(consnonna,2))
   for j=firstnonna+1:lastnonna
      s(j)=s(j-1)*s(j)
   end
   s(lastnonna+1:size(s,1))=%nan
end

ts('series')=s
