function [resacf]=acf(grocer_namey,varargin)

// PURPOSE: find sample autocorrelation coefficients 
//---------------------------------------------------
// INPUT:
// * namey = a time series, a real (nx1) vector or a string equal to the name of a time series or a (nx1) real vector between quotes
// * argi = (optional) string arguments that can be:
//   - 'noplt' if the user does not want to plot the autocorrelation coefficients 
//   - 'm=xx' where xx is the number of calculated coefficients (default: floor(size(grocer_y,'*')/4)
//   - 'size=xx' where xx is the size of the confidence band (default: 0.05)
//---------------------------------------------------
// OUTPUT:
// resacf = a tlist with
//   . resacf('meth')   = 'acf'
//   . resacf('y')      = values of the input variable
//   . resacf('acf')   = autocorrelation coeffcients
//   . resacf('acf_l') = low bound of the confidence interval
//   . resacf('acf_u') = upper bound of the confidence interval
//   . resacf('size') = size of the confidence band
//   . resacf('namey') = name of variable
//   . resacf('prests') = %t if variable is a ts
// --------------------------------------------------
// Copyright INRIA/ Eric Dubois 2004

// explode namey into the corresponding variable, its name, if
// it's a ts and if necessary the admissible bounds
[grocer_y,grocer_namey,grocer_prests,grocer_boundsvarb]=...
exploy(grocer_namey)

if grocer_prests then
   grocer_y=ts2vec(grocer_y,grocer_boundsvarb)
end

// set defaults
grocer_plt=%t
grocer_size=0.05
grocer_m=size(grocer_y,'*')/4
grocer_styleg=[]

nargin=length(varargin)
for grocer_i=1:nargin
   if varargin(grocer_i) == 'noplt' then
      grocer_plt=%f
   elseif typeof(varargin(grocer_i)) == 'string' then
      if part(varargin(grocer_i),1:2) == 'm=' then
         execstr('grocer_'+varargin(grocer_i))
      elseif part(varargin(grocer_i),1:5) == 'size=' then
         execstr('grocer_'+varargin(grocer_i))
      elseif part(varargin(grocer_i),1:7) == 'styleg=' then
         execstr('grocer_'+varargin(grocer_i))
      end
   elseif then
      error(typeof(varargin(grocer_i))+' is not authorized in acf for ...
      entry '+string(grcoer_varargin(grocer_i)))
   end
end

[cov,Mean]=corr(grocer_y,grocer_m+1);
ac=cov/cov(1);
varac=cumsum(2*(ac.^2))/size(grocer_y,'*')

bandsize=cdfnor("X",0,1,grocer_size/2,1-grocer_size/2) 
ul = bandsize*sqrt(varac)
ll = -bandsize*sqrt(varac)

resacf=tlist(['results';'meth';'y';'acf';'acf_l';'acf_u';...
'size';'namey';'prests'],...
'acf',grocer_y,ac(2:$)',ll(2:$)',ul(2:$)',grocer_size,grocer_namey,grocer_prests)

if grocer_prests then
   resacf(1)($+1) = 'bounds'
   resacf('bounds')=grocer_boundsvarb
end

if grocer_plt then
// the user has not entered 'noplt' as an argument
  if grocer_styleg == [] then
     pltacf(resacf)
  else
     pltacf(resacf,'styleg='+string(grocer_styleg))
  end
end

