function [AR,ARS,MA,MAS,V,G]=theta2arm2(theta,theta2mat,fromgrad)

// PURPOSE: recovers the matrices of an ARMA process from the
// values of the estimated parameters
// ------------------------------------------------------------
// INPUT:
// * theta = (npx1) vector of parameters
// * theta2mat = a string vetor of instructions that transforms
//   theta into the matrices FR, FS, AR, AS, V and G
// * fromgrad = if not given, forces the matrix V to be 
//   positive definite
// ------------------------------------------------------------
// OUPTUT:
// FR,FS,AR,AS,V,G = matrices of the process:
// (I + FR1B +...+FRpB^p)(I + FS1B^s +...+ FSpsB^pss) y(t) 
// = (G0 + G1B +...+ GtB^l) u(t) +
// (I + AR1B +...+ARqB^q)(I + AS1B^s +...+ ASqsB^qss) a(t)
//
// with Var(a(t)) = V
// ------------------------------------------------------------
// Copyright: Jaime Terceiro, 1997/
// Eric Dubois 2003 for the scilab translation

[nargout,nargin]=argn(0)
// gets the matrices in the function in order to transform them
// through theta2mat 
AR=grocer_AR
ARS=grocer_ARS
MA=grocer_MA
MAS=grocer_MAS
V=grocer_V
G=G
execstr(theta2mat)

// Force V positive definite
if nargin<3 then
  if ~E4OPTION(5) then
    if min(spec(V))<=0 then
      Vu = cholp(V);
      V = Vu'*Vu;
    end
  else
    V = V*V';
  end
end
