function [F,A,V,G]=theta2arma(theta,theta2mat)

// PURPOSE: Converts a VARMA model to reduced form VARMAX notation.
// The input arguments corresponding to the model:
//   (I + AR1B + ... +ARpB^p)(I + ARS1B^s + ... + ARSpsB^pss) y(t) = 
//   (G0 + G1B + ... + GtB^l) u(t) +
//   (I + MA1B + ... + MAqB^q)(I + MAS1B^s + ... + MASqsB^qss) a(t)
// are transformed to
//   F(B)y(t) = G(B)u(t) + A(B)e(t)
// ------------------------------------------------------------
// INPUT:
// * theta = (npx1) vector of parameters
// * thetamat = a string vetor of instructions that transforms
//   theta into the matrices AR, ARS, MA, MAS, V and G
// ------------------------------------------------------------
// OUTPUT:
// * F = the MA part of the model 
// * A = the MA part of the model
// * G = the coefficients matrix for the endogenous variables
// * V = the (mxm) (var-covar) matrix
// ------------------------------------------------------------
// Copyright Jaime Terceiro, 1997
// Eric Dubois 2003 for the Scilab translation and adpatation
 
[AR,ARS,MA,MAS,V,G0] = theta2arm2(theta,theta2mat);
if grocer_e4_type>1 then
  error('Incorrect model');
end
m=grocer_e4_m 
k=grocer_e4_k 
s=grocer_e4_s 
r=grocer_e4_r 
q=grocer_e4_q 

F = eye(m,(1+k)*m);
A = eye(m,(1+k)*m);
G = zeros(m,(1+k)*r);
if r then
  G(:,1:r*(grocer_e4_g+1)) = G0;
end
 
F(:,m+1:m*(grocer_e4_p+1)) = AR;
for i = 1:grocer_e4_P
  i1=i*s*m+1:(i*s+1)*m
  i2=(i-1)*m+1:i*m
  F(:,i1) = ...
    F(:,i1)+ARS(:,i2);
  for j = 1:grocer_e4_p
    j1=(i*s+j)*m+1:(i*s+j+1)*m
    F(:,j1) = ...
      F(:,j1)+...
      AR(:,(j-1)*m+1:j*m)*ARS(:,i2);
  end
end
 
A(:,m+1:m*(q+1)) = MA;
for i = 1:grocer_e4_Q
  i1=i*s*m+1:(i*s+1)*m
  i2=(i-1)*m+1:i*m
  A(:,i1) = ...
    A(:,i1)+MAS(:,i2);
  for j = 1:grocer_e4_q
    j1=(i*s+j)*m+1:(i*s+j+1)*m
    A(:,j1) = ...
      A(:,j1)+...
      MA(:,(j-1)*m+1:j*m)*MAS(:,i2);
  end
end
